# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attribute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
import evpn_connector.bgp.generated.gobgp_pb2 as gobgp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x61ttribute.proto\x12\x05\x61pipb\x1a\x19google/protobuf/any.proto\x1a\x0bgobgp.proto\"!\n\x0fOriginAttribute\x12\x0e\n\x06origin\x18\x01 \x01(\r\"\x9e\x01\n\tAsSegment\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.apipb.AsSegment.Type\x12\x0f\n\x07numbers\x18\x02 \x03(\r\"[\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41S_SET\x10\x01\x12\x0f\n\x0b\x41S_SEQUENCE\x10\x02\x12\x16\n\x12\x41S_CONFED_SEQUENCE\x10\x03\x12\x11\n\rAS_CONFED_SET\x10\x04\"5\n\x0f\x41sPathAttribute\x12\"\n\x08segments\x18\x01 \x03(\x0b\x32\x10.apipb.AsSegment\"$\n\x10NextHopAttribute\x12\x10\n\x08next_hop\x18\x01 \x01(\t\"%\n\x16MultiExitDiscAttribute\x12\x0b\n\x03med\x18\x01 \x01(\r\"(\n\x12LocalPrefAttribute\x12\x12\n\nlocal_pref\x18\x01 \x01(\r\"\x1a\n\x18\x41tomicAggregateAttribute\"3\n\x13\x41ggregatorAttribute\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"+\n\x14\x43ommunitiesAttribute\x12\x13\n\x0b\x63ommunities\x18\x01 \x03(\r\"#\n\x15OriginatorIdAttribute\x12\n\n\x02id\x18\x01 \x01(\t\"#\n\x14\x43lusterListAttribute\x12\x0b\n\x03ids\x18\x01 \x03(\t\"5\n\x0fIPAddressPrefix\x12\x12\n\nprefix_len\x18\x01 \x01(\r\x12\x0e\n\x06prefix\x18\x02 \x01(\t\"L\n\x16LabeledIPAddressPrefix\x12\x0e\n\x06labels\x18\x01 \x03(\r\x12\x12\n\nprefix_len\x18\x02 \x01(\r\x12\x0e\n\x06prefix\x18\x03 \x01(\t\"$\n\x11\x45ncapsulationNLRI\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"@\n\x1dRouteDistinguisherTwoOctetASN\x12\r\n\x05\x61\x64min\x18\x01 \x01(\r\x12\x10\n\x08\x61ssigned\x18\x02 \x01(\r\">\n\x1bRouteDistinguisherIPAddress\x12\r\n\x05\x61\x64min\x18\x01 \x01(\t\x12\x10\n\x08\x61ssigned\x18\x02 \x01(\r\"A\n\x1eRouteDistinguisherFourOctetASN\x12\r\n\x05\x61\x64min\x18\x01 \x01(\r\x12\x10\n\x08\x61ssigned\x18\x02 \x01(\r\"8\n\x19\x45thernetSegmentIdentifier\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x85\x01\n\x08VPLSNLRI\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\r\n\x05ve_id\x18\x02 \x01(\r\x12\x17\n\x0fve_block_offset\x18\x03 \x01(\r\x12\x15\n\rve_block_size\x18\x04 \x01(\r\x12\x18\n\x10label_block_base\x18\x05 \x01(\r\"\x96\x01\n\x1e\x45VPNEthernetAutoDiscoveryRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\x03\x65si\x18\x02 \x01(\x0b\x32 .apipb.EthernetSegmentIdentifier\x12\x14\n\x0c\x65thernet_tag\x18\x03 \x01(\r\x12\r\n\x05label\x18\x04 \x01(\r\"\xbd\x01\n\x1b\x45VPNMACIPAdvertisementRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\x03\x65si\x18\x02 \x01(\x0b\x32 .apipb.EthernetSegmentIdentifier\x12\x14\n\x0c\x65thernet_tag\x18\x03 \x01(\r\x12\x13\n\x0bmac_address\x18\x04 \x01(\t\x12\x12\n\nip_address\x18\x05 \x01(\t\x12\x0e\n\x06labels\x18\x06 \x03(\r\"t\n&EVPNInclusiveMulticastEthernetTagRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x14\n\x0c\x65thernet_tag\x18\x02 \x01(\r\x12\x12\n\nip_address\x18\x03 \x01(\t\"\x7f\n\x18\x45VPNEthernetSegmentRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\x03\x65si\x18\x02 \x01(\x0b\x32 .apipb.EthernetSegmentIdentifier\x12\x12\n\nip_address\x18\x03 \x01(\t\"\xc7\x01\n\x11\x45VPNIPPrefixRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\x03\x65si\x18\x02 \x01(\x0b\x32 .apipb.EthernetSegmentIdentifier\x12\x14\n\x0c\x65thernet_tag\x18\x03 \x01(\r\x12\x11\n\tip_prefix\x18\x04 \x01(\t\x12\x15\n\rip_prefix_len\x18\x05 \x01(\r\x12\x12\n\ngw_address\x18\x06 \x01(\t\x12\r\n\x05label\x18\x07 \x01(\r\"j\n\x0e\x45VPNIPMSIRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x14\n\x0c\x65thernet_tag\x18\x02 \x01(\r\x12 \n\x02rt\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"V\n\x0cSRPolicyNLRI\x12\x0e\n\x06length\x18\x01 \x01(\r\x12\x15\n\rdistinguisher\x18\x02 \x01(\r\x12\r\n\x05\x63olor\x18\x03 \x01(\r\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\x0c\"q\n\x19LabeledVPNIPAddressPrefix\x12\x0e\n\x06labels\x18\x01 \x03(\r\x12 \n\x02rd\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x12\n\nprefix_len\x18\x03 \x01(\r\x12\x0e\n\x06prefix\x18\x04 \x01(\t\"J\n\x19RouteTargetMembershipNLRI\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12 \n\x02rt\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"T\n\x10\x46lowSpecIPPrefix\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x12\n\nprefix_len\x18\x02 \x01(\r\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\r\",\n\x0b\x46lowSpecMAC\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"2\n\x15\x46lowSpecComponentItem\x12\n\n\x02op\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x04\"N\n\x11\x46lowSpecComponent\x12\x0c\n\x04type\x18\x01 \x01(\r\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.apipb.FlowSpecComponentItem\"3\n\x0c\x46lowSpecNLRI\x12#\n\x05rules\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"X\n\x0fVPNFlowSpecNLRI\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12#\n\x05rules\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\"(\n\nOpaqueNLRI\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\"\xac\x01\n\x10LsNodeDescriptor\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x11\n\tbgp_ls_id\x18\x02 \x01(\r\x12\x14\n\x0cospf_area_id\x18\x03 \x01(\r\x12\x12\n\npseudonode\x18\x04 \x01(\x08\x12\x15\n\rigp_router_id\x18\x05 \x01(\t\x12\x15\n\rbgp_router_id\x18\x06 \x01(\t\x12 \n\x18\x62gp_confederation_member\x18\x07 \x01(\r\"\xb3\x01\n\x10LsLinkDescriptor\x12\x15\n\rlink_local_id\x18\x01 \x01(\r\x12\x16\n\x0elink_remote_id\x18\x02 \x01(\r\x12\x1b\n\x13interface_addr_ipv4\x18\x03 \x01(\t\x12\x1a\n\x12neighbor_addr_ipv4\x18\x04 \x01(\t\x12\x1b\n\x13interface_addr_ipv6\x18\x05 \x01(\t\x12\x1a\n\x12neighbor_addr_ipv6\x18\x06 \x01(\t\"^\n\x12LsPrefixDescriptor\x12\x17\n\x0fip_reachability\x18\x01 \x03(\t\x12/\n\x0fospf_route_type\x18\x02 \x01(\x0e\x32\x16.apipb.LsOspfRouteType\"9\n\nLsNodeNLRI\x12+\n\nlocal_node\x18\x01 \x01(\x0b\x32\x17.apipb.LsNodeDescriptor\"\x99\x01\n\nLsLinkNLRI\x12+\n\nlocal_node\x18\x01 \x01(\x0b\x32\x17.apipb.LsNodeDescriptor\x12,\n\x0bremote_node\x18\x02 \x01(\x0b\x32\x17.apipb.LsNodeDescriptor\x12\x30\n\x0flink_descriptor\x18\x03 \x01(\x0b\x32\x17.apipb.LsLinkDescriptor\"s\n\x0eLsPrefixV4NLRI\x12+\n\nlocal_node\x18\x01 \x01(\x0b\x32\x17.apipb.LsNodeDescriptor\x12\x34\n\x11prefix_descriptor\x18\x02 \x01(\x0b\x32\x19.apipb.LsPrefixDescriptor\"s\n\x0eLsPrefixV6NLRI\x12+\n\nlocal_node\x18\x01 \x01(\x0b\x32\x17.apipb.LsNodeDescriptor\x12\x34\n\x11prefix_descriptor\x18\x02 \x01(\x0b\x32\x19.apipb.LsPrefixDescriptor\"\xa1\x01\n\x0cLsAddrPrefix\x12\x1f\n\x04type\x18\x01 \x01(\x0e\x32\x11.apipb.LsNLRIType\x12\"\n\x04nlri\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06length\x18\x03 \x01(\r\x12(\n\x0bprotocol_id\x18\x04 \x01(\x0e\x32\x13.apipb.LsProtocolID\x12\x12\n\nidentifier\x18\x05 \x01(\x04\"U\n!MUPInterworkSegmentDiscoveryRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06prefix\x18\x02 \x01(\t\"S\n\x1eMUPDirectSegmentDiscoveryRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"\xc4\x01\n\x1fMUPType1SessionTransformedRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x19\n\rprefix_length\x18\x02 \x01(\rB\x02\x18\x01\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x0c\n\x04teid\x18\x04 \x01(\r\x12\x0b\n\x03qfi\x18\x05 \x01(\r\x12\x1f\n\x17\x65ndpoint_address_length\x18\x06 \x01(\r\x12\x18\n\x10\x65ndpoint_address\x18\x07 \x01(\t\"\x8c\x01\n\x1fMUPType2SessionTransformedRoute\x12 \n\x02rd\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x1f\n\x17\x65ndpoint_address_length\x18\x02 \x01(\r\x12\x18\n\x10\x65ndpoint_address\x18\x03 \x01(\t\x12\x0c\n\x04teid\x18\x04 \x01(\r\"m\n\x14MpReachNLRIAttribute\x12\x1d\n\x06\x66\x61mily\x18\x01 \x01(\x0b\x32\r.apipb.Family\x12\x11\n\tnext_hops\x18\x02 \x03(\t\x12#\n\x05nlris\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Any\"\\\n\x16MpUnreachNLRIAttribute\x12\x1d\n\x06\x66\x61mily\x18\x01 \x01(\x0b\x32\r.apipb.Family\x12#\n\x05nlris\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Any\"g\n\x1aTwoOctetAsSpecificExtended\x12\x15\n\ris_transitive\x18\x01 \x01(\x08\x12\x10\n\x08sub_type\x18\x02 \x01(\r\x12\x0b\n\x03\x61sn\x18\x03 \x01(\r\x12\x13\n\x0blocal_admin\x18\x04 \x01(\r\"l\n\x1bIPv4AddressSpecificExtended\x12\x15\n\ris_transitive\x18\x01 \x01(\x08\x12\x10\n\x08sub_type\x18\x02 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x13\n\x0blocal_admin\x18\x04 \x01(\r\"h\n\x1b\x46ourOctetAsSpecificExtended\x12\x15\n\ris_transitive\x18\x01 \x01(\x08\x12\x10\n\x08sub_type\x18\x02 \x01(\r\x12\x0b\n\x03\x61sn\x18\x03 \x01(\r\x12\x13\n\x0blocal_admin\x18\x04 \x01(\r\"7\n\x15LinkBandwidthExtended\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x11\n\tbandwidth\x18\x02 \x01(\x02\"#\n\x12ValidationExtended\x12\r\n\x05state\x18\x01 \x01(\r\"\x1e\n\rColorExtended\x12\r\n\x05\x63olor\x18\x01 \x01(\r\"$\n\rEncapExtended\x12\x13\n\x0btunnel_type\x18\x01 \x01(\r\"\x18\n\x16\x44\x65\x66\x61ultGatewayExtended\"6\n\x0eOpaqueExtended\x12\x15\n\ris_transitive\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x03 \x01(\x0c\";\n\x10\x45SILabelExtended\x12\x18\n\x10is_single_active\x18\x01 \x01(\x08\x12\r\n\x05label\x18\x02 \x01(\r\"(\n\x13\x45SImportRouteTarget\x12\x11\n\tes_import\x18\x01 \x01(\t\">\n\x13MacMobilityExtended\x12\x11\n\tis_sticky\x18\x01 \x01(\x08\x12\x14\n\x0csequence_num\x18\x02 \x01(\r\" \n\x11RouterMacExtended\x12\x0b\n\x03mac\x18\x01 \x01(\t\"0\n\x13TrafficRateExtended\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x0c\n\x04rate\x18\x02 \x01(\x02\"9\n\x15TrafficActionExtended\x12\x10\n\x08terminal\x18\x01 \x01(\x08\x12\x0e\n\x06sample\x18\x02 \x01(\x08\"F\n\"RedirectTwoOctetAsSpecificExtended\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x13\n\x0blocal_admin\x18\x02 \x01(\r\"K\n#RedirectIPv4AddressSpecificExtended\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x0blocal_admin\x18\x02 \x01(\r\"G\n#RedirectFourOctetAsSpecificExtended\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x13\n\x0blocal_admin\x18\x02 \x01(\r\"%\n\x15TrafficRemarkExtended\x12\x0c\n\x04\x64scp\x18\x01 \x01(\r\"I\n\x0bMUPExtended\x12\x10\n\x08sub_type\x18\x01 \x01(\r\x12\x13\n\x0bsegment_id2\x18\x02 \x01(\r\x12\x13\n\x0bsegment_id4\x18\x03 \x01(\r\"2\n\x0cVPLSExtended\x12\x15\n\rcontrol_flags\x18\x01 \x01(\r\x12\x0b\n\x03mtu\x18\x02 \x01(\r\".\n\x0fUnknownExtended\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x0c\"I\n\x1c\x45xtendedCommunitiesAttribute\x12)\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"6\n\x10\x41s4PathAttribute\x12\"\n\x08segments\x18\x01 \x03(\x0b\x32\x10.apipb.AsSegment\"6\n\x16\x41s4AggregatorAttribute\x12\x0b\n\x03\x61sn\x18\x02 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"M\n\x13PmsiTunnelAttribute\x12\r\n\x05\x66lags\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\r\n\x05label\x18\x03 \x01(\r\x12\n\n\x02id\x18\x04 \x01(\x0c\"=\n\x1eTunnelEncapSubTLVEncapsulation\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x0e\n\x06\x63ookie\x18\x02 \x01(\x0c\"-\n\x19TunnelEncapSubTLVProtocol\x12\x10\n\x08protocol\x18\x01 \x01(\r\"\'\n\x16TunnelEncapSubTLVColor\x12\r\n\x05\x63olor\x18\x01 \x01(\r\"B\n\x1dTunnelEncapSubTLVSRPreference\x12\r\n\x05\x66lags\x18\x01 \x01(\r\x12\x12\n\npreference\x18\x02 \x01(\r\"C\n$TunnelEncapSubTLVSRCandidatePathName\x12\x1b\n\x13\x63\x61ndidate_path_name\x18\x01 \x01(\t\"/\n\x1bTunnelEncapSubTLVSRPriority\x12\x10\n\x08priority\x18\x01 \x01(\r\"C\n\x1dTunnelEncapSubTLVSRBindingSID\x12\"\n\x04\x62sid\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\";\n\x0cSRBindingSID\x12\x0e\n\x06s_flag\x18\x01 \x01(\x08\x12\x0e\n\x06i_flag\x18\x02 \x01(\x08\x12\x0b\n\x03sid\x18\x03 \x01(\x0c\"\x85\x01\n\x14SRv6EndPointBehavior\x12%\n\x08\x62\x65havior\x18\x01 \x01(\x0e\x32\x13.apipb.SRv6Behavior\x12\x11\n\tblock_len\x18\x02 \x01(\r\x12\x10\n\x08node_len\x18\x03 \x01(\r\x12\x10\n\x08\x66unc_len\x18\x04 \x01(\r\x12\x0f\n\x07\x61rg_len\x18\x05 \x01(\r\"\x8f\x01\n\x0eSRv6BindingSID\x12\x0e\n\x06s_flag\x18\x01 \x01(\x08\x12\x0e\n\x06i_flag\x18\x02 \x01(\x08\x12\x0e\n\x06\x62_flag\x18\x03 \x01(\x08\x12\x0b\n\x03sid\x18\x04 \x01(\x0c\x12@\n\x1b\x65ndpoint_behavior_structure\x18\x05 \x01(\x0b\x32\x1b.apipb.SRv6EndPointBehavior\"G\n\x17TunnelEncapSubTLVSRENLP\x12\r\n\x05\x66lags\x18\x01 \x01(\r\x12\x1d\n\x04\x65nlp\x18\x02 \x01(\x0e\x32\x0f.apipb.ENLPType\")\n\x08SRWeight\x12\r\n\x05\x66lags\x18\x01 \x01(\r\x12\x0e\n\x06weight\x18\x02 \x01(\r\"N\n\x0cSegmentFlags\x12\x0e\n\x06v_flag\x18\x01 \x01(\x08\x12\x0e\n\x06\x61_flag\x18\x02 \x01(\x08\x12\x0e\n\x06s_flag\x18\x03 \x01(\x08\x12\x0e\n\x06\x62_flag\x18\x04 \x01(\x08\"A\n\x0cSegmentTypeA\x12\"\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x13.apipb.SegmentFlags\x12\r\n\x05label\x18\x02 \x01(\r\"\x81\x01\n\x0cSegmentTypeB\x12\"\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x13.apipb.SegmentFlags\x12\x0b\n\x03sid\x18\x02 \x01(\x0c\x12@\n\x1b\x65ndpoint_behavior_structure\x18\x03 \x01(\x0b\x32\x1b.apipb.SRv6EndPointBehavior\"i\n\x1eTunnelEncapSubTLVSRSegmentList\x12\x1f\n\x06weight\x18\x01 \x01(\x0b\x32\x0f.apipb.SRWeight\x12&\n\x08segments\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\"2\n\x1fTunnelEncapSubTLVEgressEndpoint\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\",\n\x1cTunnelEncapSubTLVUDPDestPort\x12\x0c\n\x04port\x18\x01 \x01(\r\"7\n\x18TunnelEncapSubTLVUnknown\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x0c\"B\n\x0eTunnelEncapTLV\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\"\n\x04tlvs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\";\n\x14TunnelEncapAttribute\x12#\n\x04tlvs\x18\x01 \x03(\x0b\x32\x15.apipb.TunnelEncapTLV\"l\n\x1bIPv6AddressSpecificExtended\x12\x15\n\ris_transitive\x18\x01 \x01(\x08\x12\x10\n\x08sub_type\x18\x02 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x13\n\x0blocal_admin\x18\x04 \x01(\r\"K\n#RedirectIPv6AddressSpecificExtended\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x0blocal_admin\x18\x02 \x01(\r\"L\n\x1fIP6ExtendedCommunitiesAttribute\x12)\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"\"\n\x10\x41igpTLVIGPMetric\x12\x0e\n\x06metric\x18\x01 \x01(\x04\"-\n\x0e\x41igpTLVUnknown\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x0c\"3\n\rAigpAttribute\x12\"\n\x04tlvs\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"P\n\x0eLargeCommunity\x12\x14\n\x0cglobal_admin\x18\x01 \x01(\r\x12\x13\n\x0blocal_data1\x18\x02 \x01(\r\x12\x13\n\x0blocal_data2\x18\x03 \x01(\r\"G\n\x19LargeCommunitiesAttribute\x12*\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\x15.apipb.LargeCommunity\"l\n\x0bLsNodeFlags\x12\x10\n\x08overload\x18\x01 \x01(\x08\x12\x10\n\x08\x61ttached\x18\x02 \x01(\x08\x12\x10\n\x08\x65xternal\x18\x03 \x01(\x08\x12\x0b\n\x03\x61\x62r\x18\x04 \x01(\x08\x12\x0e\n\x06router\x18\x05 \x01(\x08\x12\n\n\x02v6\x18\x06 \x01(\x08\"]\n\nLsIGPFlags\x12\x0c\n\x04\x64own\x18\x01 \x01(\x08\x12\x12\n\nno_unicast\x18\x02 \x01(\x08\x12\x15\n\rlocal_address\x18\x03 \x01(\x08\x12\x16\n\x0epropagate_nssa\x18\x04 \x01(\x08\"\'\n\tLsSrRange\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\r\x12\x0b\n\x03\x65nd\x18\x02 \x01(\r\"d\n\x10LsSrCapabilities\x12\x16\n\x0eipv4_supported\x18\x01 \x01(\x08\x12\x16\n\x0eipv6_supported\x18\x02 \x01(\x08\x12 \n\x06ranges\x18\x03 \x03(\x0b\x32\x10.apipb.LsSrRange\"2\n\x0eLsSrLocalBlock\x12 \n\x06ranges\x18\x01 \x03(\x0b\x32\x10.apipb.LsSrRange\"\x92\x02\n\x0fLsAttributeNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12!\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x12.apipb.LsNodeFlags\x12\x17\n\x0flocal_router_id\x18\x03 \x01(\t\x12\x1a\n\x12local_router_id_v6\x18\x04 \x01(\t\x12\x11\n\tisis_area\x18\x05 \x01(\x0c\x12\x0e\n\x06opaque\x18\x06 \x01(\x0c\x12\x30\n\x0fsr_capabilities\x18\x07 \x01(\x0b\x32\x17.apipb.LsSrCapabilities\x12\x15\n\rsr_algorithms\x18\x08 \x01(\x0c\x12-\n\x0esr_local_block\x18\t \x01(\x0b\x32\x15.apipb.LsSrLocalBlock\"\xd7\x02\n\x0fLsAttributeLink\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0flocal_router_id\x18\x02 \x01(\t\x12\x1a\n\x12local_router_id_v6\x18\x03 \x01(\t\x12\x18\n\x10remote_router_id\x18\x04 \x01(\t\x12\x1b\n\x13remote_router_id_v6\x18\x05 \x01(\t\x12\x13\n\x0b\x61\x64min_group\x18\x06 \x01(\r\x12\x19\n\x11\x64\x65\x66\x61ult_te_metric\x18\x07 \x01(\r\x12\x12\n\nigp_metric\x18\x08 \x01(\r\x12\x0e\n\x06opaque\x18\t \x01(\x0c\x12\x11\n\tbandwidth\x18\n \x01(\x02\x12\x1c\n\x14reservable_bandwidth\x18\x0b \x01(\x02\x12\x1c\n\x14unreserved_bandwidth\x18\x0c \x03(\x02\x12\x18\n\x10sr_adjacency_sid\x18\r \x01(\r\x12\r\n\x05srlgs\x18\x0e \x03(\r\"`\n\x11LsAttributePrefix\x12$\n\tigp_flags\x18\x01 \x01(\x0b\x32\x11.apipb.LsIGPFlags\x12\x0e\n\x06opaque\x18\x02 \x01(\x0c\x12\x15\n\rsr_prefix_sid\x18\x03 \x01(\r\"\\\n\x18LsBgpPeerSegmentSIDFlags\x12\r\n\x05value\x18\x01 \x01(\x08\x12\r\n\x05local\x18\x02 \x01(\x08\x12\x0e\n\x06\x62\x61\x63kup\x18\x03 \x01(\x08\x12\x12\n\npersistent\x18\x04 \x01(\x08\"b\n\x13LsBgpPeerSegmentSID\x12.\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1f.apipb.LsBgpPeerSegmentSIDFlags\x12\x0e\n\x06weight\x18\x02 \x01(\r\x12\x0b\n\x03sid\x18\x03 \x01(\r\"\xc4\x01\n\x19LsAttributeBgpPeerSegment\x12\x35\n\x11\x62gp_peer_node_sid\x18\x01 \x01(\x0b\x32\x1a.apipb.LsBgpPeerSegmentSID\x12:\n\x16\x62gp_peer_adjacency_sid\x18\x02 \x01(\x0b\x32\x1a.apipb.LsBgpPeerSegmentSID\x12\x34\n\x10\x62gp_peer_set_sid\x18\x03 \x01(\x0b\x32\x1a.apipb.LsBgpPeerSegmentSID\"\xbf\x01\n\x0bLsAttribute\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x16.apipb.LsAttributeNode\x12$\n\x04link\x18\x02 \x01(\x0b\x32\x16.apipb.LsAttributeLink\x12(\n\x06prefix\x18\x03 \x01(\x0b\x32\x18.apipb.LsAttributePrefix\x12:\n\x10\x62gp_peer_segment\x18\x04 \x01(\x0b\x32 .apipb.LsAttributeBgpPeerSegment\">\n\x10UnknownAttribute\x12\r\n\x05\x66lags\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\r\n\x05value\x18\x03 \x01(\x0c\"\xc1\x01\n\x16SRv6StructureSubSubTLV\x12\x1c\n\x14locator_block_length\x18\x01 \x01(\r\x12\x1b\n\x13locator_node_length\x18\x02 \x01(\r\x12\x17\n\x0f\x66unction_length\x18\x03 \x01(\r\x12\x17\n\x0f\x61rgument_length\x18\x04 \x01(\r\x12\x1c\n\x14transposition_length\x18\x05 \x01(\r\x12\x1c\n\x14transposition_offset\x18\x06 \x01(\r\"\x1e\n\x0cSRv6SIDFlags\x12\x0e\n\x06\x66lag_1\x18\x01 \x01(\x08\",\n\x07SRv6TLV\x12!\n\x03tlv\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"\xea\x01\n\x15SRv6InformationSubTLV\x12\x0b\n\x03sid\x18\x01 \x01(\x0c\x12\"\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x13.apipb.SRv6SIDFlags\x12\x19\n\x11\x65ndpoint_behavior\x18\x03 \x01(\r\x12\x42\n\x0csub_sub_tlvs\x18\x04 \x03(\x0b\x32,.apipb.SRv6InformationSubTLV.SubSubTlvsEntry\x1a\x41\n\x0fSubSubTlvsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.apipb.SRv6TLV:\x02\x38\x01\"\x8a\x01\n\x10SRv6L3ServiceTLV\x12\x36\n\x08sub_tlvs\x18\x01 \x03(\x0b\x32$.apipb.SRv6L3ServiceTLV.SubTlvsEntry\x1a>\n\x0cSubTlvsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.apipb.SRv6TLV:\x02\x38\x01\"\x8a\x01\n\x10SRv6L2ServiceTLV\x12\x36\n\x08sub_tlvs\x18\x01 \x03(\x0b\x32$.apipb.SRv6L2ServiceTLV.SubTlvsEntry\x1a>\n\x0cSubTlvsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.apipb.SRv6TLV:\x02\x38\x01\"/\n\tPrefixSID\x12\"\n\x04tlvs\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any*\xf7\x01\n\x0fLsOspfRouteType\x12\x1e\n\x1aLS_OSPF_ROUTE_TYPE_UNKNOWN\x10\x00\x12!\n\x1dLS_OSPF_ROUTE_TYPE_INTRA_AREA\x10\x01\x12!\n\x1dLS_OSPF_ROUTE_TYPE_INTER_AREA\x10\x02\x12 \n\x1cLS_OSPF_ROUTE_TYPE_EXTERNAL1\x10\x03\x12 \n\x1cLS_OSPF_ROUTE_TYPE_EXTERNAL2\x10\x04\x12\x1c\n\x18LS_OSPF_ROUTE_TYPE_NSSA1\x10\x05\x12\x1c\n\x18LS_OSPF_ROUTE_TYPE_NSSA2\x10\x06*s\n\nLsNLRIType\x12\x13\n\x0fLS_NLRI_UNKNOWN\x10\x00\x12\x10\n\x0cLS_NLRI_NODE\x10\x01\x12\x10\n\x0cLS_NLRI_LINK\x10\x02\x12\x15\n\x11LS_NLRI_PREFIX_V4\x10\x03\x12\x15\n\x11LS_NLRI_PREFIX_V6\x10\x04*\xbb\x01\n\x0cLsProtocolID\x12\x17\n\x13LS_PROTOCOL_UNKNOWN\x10\x00\x12\x17\n\x13LS_PROTOCOL_ISIS_L1\x10\x01\x12\x17\n\x13LS_PROTOCOL_ISIS_L2\x10\x02\x12\x17\n\x13LS_PROTOCOL_OSPF_V2\x10\x03\x12\x16\n\x12LS_PROTOCOL_DIRECT\x10\x04\x12\x16\n\x12LS_PROTOCOL_STATIC\x10\x05\x12\x17\n\x13LS_PROTOCOL_OSPF_V3\x10\x06*\xed\x05\n\x0cSRv6Behavior\x12\x0c\n\x08RESERVED\x10\x00\x12\x07\n\x03\x45ND\x10\x01\x12\x10\n\x0c\x45ND_WITH_PSP\x10\x02\x12\x10\n\x0c\x45ND_WITH_USP\x10\x03\x12\x14\n\x10\x45ND_WITH_PSP_USP\x10\x04\x12\x08\n\x04\x45NDX\x10\x05\x12\x11\n\rENDX_WITH_PSP\x10\x06\x12\x11\n\rENDX_WITH_USP\x10\x07\x12\x15\n\x11\x45NDX_WITH_PSP_USP\x10\x08\x12\x08\n\x04\x45NDT\x10\t\x12\x11\n\rENDT_WITH_PSP\x10\n\x12\x11\n\rENDT_WITH_USP\x10\x0b\x12\x15\n\x11\x45NDT_WITH_PSP_USP\x10\x0c\x12\x11\n\rEND_B6_ENCAPS\x10\x0e\x12\n\n\x06\x45ND_BM\x10\x0f\x12\x0b\n\x07\x45ND_DX6\x10\x10\x12\x0b\n\x07\x45ND_DX4\x10\x11\x12\x0b\n\x07\x45ND_DT6\x10\x12\x12\x0b\n\x07\x45ND_DT4\x10\x13\x12\x0c\n\x08\x45ND_DT46\x10\x14\x12\x0b\n\x07\x45ND_DX2\x10\x15\x12\x0c\n\x08\x45ND_DX2V\x10\x16\x12\x0c\n\x08\x45ND_DT2U\x10\x17\x12\x0c\n\x08\x45ND_DT2M\x10\x18\x12\x15\n\x11\x45ND_B6_ENCAPS_Red\x10\x1b\x12\x10\n\x0c\x45ND_WITH_USD\x10\x1c\x12\x14\n\x10\x45ND_WITH_PSP_USD\x10\x1d\x12\x14\n\x10\x45ND_WITH_USP_USD\x10\x1e\x12\x18\n\x14\x45ND_WITH_PSP_USP_USD\x10\x1f\x12\x11\n\rENDX_WITH_USD\x10 \x12\x15\n\x11\x45NDX_WITH_PSP_USD\x10!\x12\x15\n\x11\x45NDX_WITH_USP_USD\x10\"\x12\x19\n\x15\x45NDX_WITH_PSP_USP_USD\x10#\x12\x11\n\rENDT_WITH_USD\x10$\x12\x15\n\x11\x45NDT_WITH_PSP_USD\x10%\x12\x15\n\x11\x45NDT_WITH_USP_USD\x10&\x12\x19\n\x15\x45NDT_WITH_PSP_USP_USD\x10\'\x12\x0e\n\nENDM_GTP6D\x10\x45\x12\x0f\n\x0b\x45NDM_GTP6DI\x10\x46\x12\x0e\n\nENDM_GTP6E\x10G\x12\x0e\n\nENDM_GTP4E\x10H*D\n\x08\x45NLPType\x12\x0c\n\x08Reserved\x10\x00\x12\t\n\x05Type1\x10\x01\x12\t\n\x05Type2\x10\x02\x12\t\n\x05Type3\x10\x03\x12\t\n\x05Type4\x10\x04\x42$Z\"github.com/osrg/gobgp/v3/api;apipbb\x06proto3')

_LSOSPFROUTETYPE = DESCRIPTOR.enum_types_by_name['LsOspfRouteType']
LsOspfRouteType = enum_type_wrapper.EnumTypeWrapper(_LSOSPFROUTETYPE)
_LSNLRITYPE = DESCRIPTOR.enum_types_by_name['LsNLRIType']
LsNLRIType = enum_type_wrapper.EnumTypeWrapper(_LSNLRITYPE)
_LSPROTOCOLID = DESCRIPTOR.enum_types_by_name['LsProtocolID']
LsProtocolID = enum_type_wrapper.EnumTypeWrapper(_LSPROTOCOLID)
_SRV6BEHAVIOR = DESCRIPTOR.enum_types_by_name['SRv6Behavior']
SRv6Behavior = enum_type_wrapper.EnumTypeWrapper(_SRV6BEHAVIOR)
_ENLPTYPE = DESCRIPTOR.enum_types_by_name['ENLPType']
ENLPType = enum_type_wrapper.EnumTypeWrapper(_ENLPTYPE)
LS_OSPF_ROUTE_TYPE_UNKNOWN = 0
LS_OSPF_ROUTE_TYPE_INTRA_AREA = 1
LS_OSPF_ROUTE_TYPE_INTER_AREA = 2
LS_OSPF_ROUTE_TYPE_EXTERNAL1 = 3
LS_OSPF_ROUTE_TYPE_EXTERNAL2 = 4
LS_OSPF_ROUTE_TYPE_NSSA1 = 5
LS_OSPF_ROUTE_TYPE_NSSA2 = 6
LS_NLRI_UNKNOWN = 0
LS_NLRI_NODE = 1
LS_NLRI_LINK = 2
LS_NLRI_PREFIX_V4 = 3
LS_NLRI_PREFIX_V6 = 4
LS_PROTOCOL_UNKNOWN = 0
LS_PROTOCOL_ISIS_L1 = 1
LS_PROTOCOL_ISIS_L2 = 2
LS_PROTOCOL_OSPF_V2 = 3
LS_PROTOCOL_DIRECT = 4
LS_PROTOCOL_STATIC = 5
LS_PROTOCOL_OSPF_V3 = 6
RESERVED = 0
END = 1
END_WITH_PSP = 2
END_WITH_USP = 3
END_WITH_PSP_USP = 4
ENDX = 5
ENDX_WITH_PSP = 6
ENDX_WITH_USP = 7
ENDX_WITH_PSP_USP = 8
ENDT = 9
ENDT_WITH_PSP = 10
ENDT_WITH_USP = 11
ENDT_WITH_PSP_USP = 12
END_B6_ENCAPS = 14
END_BM = 15
END_DX6 = 16
END_DX4 = 17
END_DT6 = 18
END_DT4 = 19
END_DT46 = 20
END_DX2 = 21
END_DX2V = 22
END_DT2U = 23
END_DT2M = 24
END_B6_ENCAPS_Red = 27
END_WITH_USD = 28
END_WITH_PSP_USD = 29
END_WITH_USP_USD = 30
END_WITH_PSP_USP_USD = 31
ENDX_WITH_USD = 32
ENDX_WITH_PSP_USD = 33
ENDX_WITH_USP_USD = 34
ENDX_WITH_PSP_USP_USD = 35
ENDT_WITH_USD = 36
ENDT_WITH_PSP_USD = 37
ENDT_WITH_USP_USD = 38
ENDT_WITH_PSP_USP_USD = 39
ENDM_GTP6D = 69
ENDM_GTP6DI = 70
ENDM_GTP6E = 71
ENDM_GTP4E = 72
Reserved = 0
Type1 = 1
Type2 = 2
Type3 = 3
Type4 = 4


_ORIGINATTRIBUTE = DESCRIPTOR.message_types_by_name['OriginAttribute']
_ASSEGMENT = DESCRIPTOR.message_types_by_name['AsSegment']
_ASPATHATTRIBUTE = DESCRIPTOR.message_types_by_name['AsPathAttribute']
_NEXTHOPATTRIBUTE = DESCRIPTOR.message_types_by_name['NextHopAttribute']
_MULTIEXITDISCATTRIBUTE = DESCRIPTOR.message_types_by_name['MultiExitDiscAttribute']
_LOCALPREFATTRIBUTE = DESCRIPTOR.message_types_by_name['LocalPrefAttribute']
_ATOMICAGGREGATEATTRIBUTE = DESCRIPTOR.message_types_by_name['AtomicAggregateAttribute']
_AGGREGATORATTRIBUTE = DESCRIPTOR.message_types_by_name['AggregatorAttribute']
_COMMUNITIESATTRIBUTE = DESCRIPTOR.message_types_by_name['CommunitiesAttribute']
_ORIGINATORIDATTRIBUTE = DESCRIPTOR.message_types_by_name['OriginatorIdAttribute']
_CLUSTERLISTATTRIBUTE = DESCRIPTOR.message_types_by_name['ClusterListAttribute']
_IPADDRESSPREFIX = DESCRIPTOR.message_types_by_name['IPAddressPrefix']
_LABELEDIPADDRESSPREFIX = DESCRIPTOR.message_types_by_name['LabeledIPAddressPrefix']
_ENCAPSULATIONNLRI = DESCRIPTOR.message_types_by_name['EncapsulationNLRI']
_ROUTEDISTINGUISHERTWOOCTETASN = DESCRIPTOR.message_types_by_name['RouteDistinguisherTwoOctetASN']
_ROUTEDISTINGUISHERIPADDRESS = DESCRIPTOR.message_types_by_name['RouteDistinguisherIPAddress']
_ROUTEDISTINGUISHERFOUROCTETASN = DESCRIPTOR.message_types_by_name['RouteDistinguisherFourOctetASN']
_ETHERNETSEGMENTIDENTIFIER = DESCRIPTOR.message_types_by_name['EthernetSegmentIdentifier']
_VPLSNLRI = DESCRIPTOR.message_types_by_name['VPLSNLRI']
_EVPNETHERNETAUTODISCOVERYROUTE = DESCRIPTOR.message_types_by_name['EVPNEthernetAutoDiscoveryRoute']
_EVPNMACIPADVERTISEMENTROUTE = DESCRIPTOR.message_types_by_name['EVPNMACIPAdvertisementRoute']
_EVPNINCLUSIVEMULTICASTETHERNETTAGROUTE = DESCRIPTOR.message_types_by_name['EVPNInclusiveMulticastEthernetTagRoute']
_EVPNETHERNETSEGMENTROUTE = DESCRIPTOR.message_types_by_name['EVPNEthernetSegmentRoute']
_EVPNIPPREFIXROUTE = DESCRIPTOR.message_types_by_name['EVPNIPPrefixRoute']
_EVPNIPMSIROUTE = DESCRIPTOR.message_types_by_name['EVPNIPMSIRoute']
_SRPOLICYNLRI = DESCRIPTOR.message_types_by_name['SRPolicyNLRI']
_LABELEDVPNIPADDRESSPREFIX = DESCRIPTOR.message_types_by_name['LabeledVPNIPAddressPrefix']
_ROUTETARGETMEMBERSHIPNLRI = DESCRIPTOR.message_types_by_name['RouteTargetMembershipNLRI']
_FLOWSPECIPPREFIX = DESCRIPTOR.message_types_by_name['FlowSpecIPPrefix']
_FLOWSPECMAC = DESCRIPTOR.message_types_by_name['FlowSpecMAC']
_FLOWSPECCOMPONENTITEM = DESCRIPTOR.message_types_by_name['FlowSpecComponentItem']
_FLOWSPECCOMPONENT = DESCRIPTOR.message_types_by_name['FlowSpecComponent']
_FLOWSPECNLRI = DESCRIPTOR.message_types_by_name['FlowSpecNLRI']
_VPNFLOWSPECNLRI = DESCRIPTOR.message_types_by_name['VPNFlowSpecNLRI']
_OPAQUENLRI = DESCRIPTOR.message_types_by_name['OpaqueNLRI']
_LSNODEDESCRIPTOR = DESCRIPTOR.message_types_by_name['LsNodeDescriptor']
_LSLINKDESCRIPTOR = DESCRIPTOR.message_types_by_name['LsLinkDescriptor']
_LSPREFIXDESCRIPTOR = DESCRIPTOR.message_types_by_name['LsPrefixDescriptor']
_LSNODENLRI = DESCRIPTOR.message_types_by_name['LsNodeNLRI']
_LSLINKNLRI = DESCRIPTOR.message_types_by_name['LsLinkNLRI']
_LSPREFIXV4NLRI = DESCRIPTOR.message_types_by_name['LsPrefixV4NLRI']
_LSPREFIXV6NLRI = DESCRIPTOR.message_types_by_name['LsPrefixV6NLRI']
_LSADDRPREFIX = DESCRIPTOR.message_types_by_name['LsAddrPrefix']
_MUPINTERWORKSEGMENTDISCOVERYROUTE = DESCRIPTOR.message_types_by_name['MUPInterworkSegmentDiscoveryRoute']
_MUPDIRECTSEGMENTDISCOVERYROUTE = DESCRIPTOR.message_types_by_name['MUPDirectSegmentDiscoveryRoute']
_MUPTYPE1SESSIONTRANSFORMEDROUTE = DESCRIPTOR.message_types_by_name['MUPType1SessionTransformedRoute']
_MUPTYPE2SESSIONTRANSFORMEDROUTE = DESCRIPTOR.message_types_by_name['MUPType2SessionTransformedRoute']
_MPREACHNLRIATTRIBUTE = DESCRIPTOR.message_types_by_name['MpReachNLRIAttribute']
_MPUNREACHNLRIATTRIBUTE = DESCRIPTOR.message_types_by_name['MpUnreachNLRIAttribute']
_TWOOCTETASSPECIFICEXTENDED = DESCRIPTOR.message_types_by_name['TwoOctetAsSpecificExtended']
_IPV4ADDRESSSPECIFICEXTENDED = DESCRIPTOR.message_types_by_name['IPv4AddressSpecificExtended']
_FOUROCTETASSPECIFICEXTENDED = DESCRIPTOR.message_types_by_name['FourOctetAsSpecificExtended']
_LINKBANDWIDTHEXTENDED = DESCRIPTOR.message_types_by_name['LinkBandwidthExtended']
_VALIDATIONEXTENDED = DESCRIPTOR.message_types_by_name['ValidationExtended']
_COLOREXTENDED = DESCRIPTOR.message_types_by_name['ColorExtended']
_ENCAPEXTENDED = DESCRIPTOR.message_types_by_name['EncapExtended']
_DEFAULTGATEWAYEXTENDED = DESCRIPTOR.message_types_by_name['DefaultGatewayExtended']
_OPAQUEEXTENDED = DESCRIPTOR.message_types_by_name['OpaqueExtended']
_ESILABELEXTENDED = DESCRIPTOR.message_types_by_name['ESILabelExtended']
_ESIMPORTROUTETARGET = DESCRIPTOR.message_types_by_name['ESImportRouteTarget']
_MACMOBILITYEXTENDED = DESCRIPTOR.message_types_by_name['MacMobilityExtended']
_ROUTERMACEXTENDED = DESCRIPTOR.message_types_by_name['RouterMacExtended']
_TRAFFICRATEEXTENDED = DESCRIPTOR.message_types_by_name['TrafficRateExtended']
_TRAFFICACTIONEXTENDED = DESCRIPTOR.message_types_by_name['TrafficActionExtended']
_REDIRECTTWOOCTETASSPECIFICEXTENDED = DESCRIPTOR.message_types_by_name['RedirectTwoOctetAsSpecificExtended']
_REDIRECTIPV4ADDRESSSPECIFICEXTENDED = DESCRIPTOR.message_types_by_name['RedirectIPv4AddressSpecificExtended']
_REDIRECTFOUROCTETASSPECIFICEXTENDED = DESCRIPTOR.message_types_by_name['RedirectFourOctetAsSpecificExtended']
_TRAFFICREMARKEXTENDED = DESCRIPTOR.message_types_by_name['TrafficRemarkExtended']
_MUPEXTENDED = DESCRIPTOR.message_types_by_name['MUPExtended']
_VPLSEXTENDED = DESCRIPTOR.message_types_by_name['VPLSExtended']
_UNKNOWNEXTENDED = DESCRIPTOR.message_types_by_name['UnknownExtended']
_EXTENDEDCOMMUNITIESATTRIBUTE = DESCRIPTOR.message_types_by_name['ExtendedCommunitiesAttribute']
_AS4PATHATTRIBUTE = DESCRIPTOR.message_types_by_name['As4PathAttribute']
_AS4AGGREGATORATTRIBUTE = DESCRIPTOR.message_types_by_name['As4AggregatorAttribute']
_PMSITUNNELATTRIBUTE = DESCRIPTOR.message_types_by_name['PmsiTunnelAttribute']
_TUNNELENCAPSUBTLVENCAPSULATION = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVEncapsulation']
_TUNNELENCAPSUBTLVPROTOCOL = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVProtocol']
_TUNNELENCAPSUBTLVCOLOR = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVColor']
_TUNNELENCAPSUBTLVSRPREFERENCE = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVSRPreference']
_TUNNELENCAPSUBTLVSRCANDIDATEPATHNAME = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVSRCandidatePathName']
_TUNNELENCAPSUBTLVSRPRIORITY = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVSRPriority']
_TUNNELENCAPSUBTLVSRBINDINGSID = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVSRBindingSID']
_SRBINDINGSID = DESCRIPTOR.message_types_by_name['SRBindingSID']
_SRV6ENDPOINTBEHAVIOR = DESCRIPTOR.message_types_by_name['SRv6EndPointBehavior']
_SRV6BINDINGSID = DESCRIPTOR.message_types_by_name['SRv6BindingSID']
_TUNNELENCAPSUBTLVSRENLP = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVSRENLP']
_SRWEIGHT = DESCRIPTOR.message_types_by_name['SRWeight']
_SEGMENTFLAGS = DESCRIPTOR.message_types_by_name['SegmentFlags']
_SEGMENTTYPEA = DESCRIPTOR.message_types_by_name['SegmentTypeA']
_SEGMENTTYPEB = DESCRIPTOR.message_types_by_name['SegmentTypeB']
_TUNNELENCAPSUBTLVSRSEGMENTLIST = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVSRSegmentList']
_TUNNELENCAPSUBTLVEGRESSENDPOINT = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVEgressEndpoint']
_TUNNELENCAPSUBTLVUDPDESTPORT = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVUDPDestPort']
_TUNNELENCAPSUBTLVUNKNOWN = DESCRIPTOR.message_types_by_name['TunnelEncapSubTLVUnknown']
_TUNNELENCAPTLV = DESCRIPTOR.message_types_by_name['TunnelEncapTLV']
_TUNNELENCAPATTRIBUTE = DESCRIPTOR.message_types_by_name['TunnelEncapAttribute']
_IPV6ADDRESSSPECIFICEXTENDED = DESCRIPTOR.message_types_by_name['IPv6AddressSpecificExtended']
_REDIRECTIPV6ADDRESSSPECIFICEXTENDED = DESCRIPTOR.message_types_by_name['RedirectIPv6AddressSpecificExtended']
_IP6EXTENDEDCOMMUNITIESATTRIBUTE = DESCRIPTOR.message_types_by_name['IP6ExtendedCommunitiesAttribute']
_AIGPTLVIGPMETRIC = DESCRIPTOR.message_types_by_name['AigpTLVIGPMetric']
_AIGPTLVUNKNOWN = DESCRIPTOR.message_types_by_name['AigpTLVUnknown']
_AIGPATTRIBUTE = DESCRIPTOR.message_types_by_name['AigpAttribute']
_LARGECOMMUNITY = DESCRIPTOR.message_types_by_name['LargeCommunity']
_LARGECOMMUNITIESATTRIBUTE = DESCRIPTOR.message_types_by_name['LargeCommunitiesAttribute']
_LSNODEFLAGS = DESCRIPTOR.message_types_by_name['LsNodeFlags']
_LSIGPFLAGS = DESCRIPTOR.message_types_by_name['LsIGPFlags']
_LSSRRANGE = DESCRIPTOR.message_types_by_name['LsSrRange']
_LSSRCAPABILITIES = DESCRIPTOR.message_types_by_name['LsSrCapabilities']
_LSSRLOCALBLOCK = DESCRIPTOR.message_types_by_name['LsSrLocalBlock']
_LSATTRIBUTENODE = DESCRIPTOR.message_types_by_name['LsAttributeNode']
_LSATTRIBUTELINK = DESCRIPTOR.message_types_by_name['LsAttributeLink']
_LSATTRIBUTEPREFIX = DESCRIPTOR.message_types_by_name['LsAttributePrefix']
_LSBGPPEERSEGMENTSIDFLAGS = DESCRIPTOR.message_types_by_name['LsBgpPeerSegmentSIDFlags']
_LSBGPPEERSEGMENTSID = DESCRIPTOR.message_types_by_name['LsBgpPeerSegmentSID']
_LSATTRIBUTEBGPPEERSEGMENT = DESCRIPTOR.message_types_by_name['LsAttributeBgpPeerSegment']
_LSATTRIBUTE = DESCRIPTOR.message_types_by_name['LsAttribute']
_UNKNOWNATTRIBUTE = DESCRIPTOR.message_types_by_name['UnknownAttribute']
_SRV6STRUCTURESUBSUBTLV = DESCRIPTOR.message_types_by_name['SRv6StructureSubSubTLV']
_SRV6SIDFLAGS = DESCRIPTOR.message_types_by_name['SRv6SIDFlags']
_SRV6TLV = DESCRIPTOR.message_types_by_name['SRv6TLV']
_SRV6INFORMATIONSUBTLV = DESCRIPTOR.message_types_by_name['SRv6InformationSubTLV']
_SRV6INFORMATIONSUBTLV_SUBSUBTLVSENTRY = _SRV6INFORMATIONSUBTLV.nested_types_by_name['SubSubTlvsEntry']
_SRV6L3SERVICETLV = DESCRIPTOR.message_types_by_name['SRv6L3ServiceTLV']
_SRV6L3SERVICETLV_SUBTLVSENTRY = _SRV6L3SERVICETLV.nested_types_by_name['SubTlvsEntry']
_SRV6L2SERVICETLV = DESCRIPTOR.message_types_by_name['SRv6L2ServiceTLV']
_SRV6L2SERVICETLV_SUBTLVSENTRY = _SRV6L2SERVICETLV.nested_types_by_name['SubTlvsEntry']
_PREFIXSID = DESCRIPTOR.message_types_by_name['PrefixSID']
_ASSEGMENT_TYPE = _ASSEGMENT.enum_types_by_name['Type']
OriginAttribute = _reflection.GeneratedProtocolMessageType('OriginAttribute', (_message.Message,), {
  'DESCRIPTOR' : _ORIGINATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.OriginAttribute)
  })
_sym_db.RegisterMessage(OriginAttribute)

AsSegment = _reflection.GeneratedProtocolMessageType('AsSegment', (_message.Message,), {
  'DESCRIPTOR' : _ASSEGMENT,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AsSegment)
  })
_sym_db.RegisterMessage(AsSegment)

AsPathAttribute = _reflection.GeneratedProtocolMessageType('AsPathAttribute', (_message.Message,), {
  'DESCRIPTOR' : _ASPATHATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AsPathAttribute)
  })
_sym_db.RegisterMessage(AsPathAttribute)

NextHopAttribute = _reflection.GeneratedProtocolMessageType('NextHopAttribute', (_message.Message,), {
  'DESCRIPTOR' : _NEXTHOPATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.NextHopAttribute)
  })
_sym_db.RegisterMessage(NextHopAttribute)

MultiExitDiscAttribute = _reflection.GeneratedProtocolMessageType('MultiExitDiscAttribute', (_message.Message,), {
  'DESCRIPTOR' : _MULTIEXITDISCATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MultiExitDiscAttribute)
  })
_sym_db.RegisterMessage(MultiExitDiscAttribute)

LocalPrefAttribute = _reflection.GeneratedProtocolMessageType('LocalPrefAttribute', (_message.Message,), {
  'DESCRIPTOR' : _LOCALPREFATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LocalPrefAttribute)
  })
_sym_db.RegisterMessage(LocalPrefAttribute)

AtomicAggregateAttribute = _reflection.GeneratedProtocolMessageType('AtomicAggregateAttribute', (_message.Message,), {
  'DESCRIPTOR' : _ATOMICAGGREGATEATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AtomicAggregateAttribute)
  })
_sym_db.RegisterMessage(AtomicAggregateAttribute)

AggregatorAttribute = _reflection.GeneratedProtocolMessageType('AggregatorAttribute', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATORATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AggregatorAttribute)
  })
_sym_db.RegisterMessage(AggregatorAttribute)

CommunitiesAttribute = _reflection.GeneratedProtocolMessageType('CommunitiesAttribute', (_message.Message,), {
  'DESCRIPTOR' : _COMMUNITIESATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.CommunitiesAttribute)
  })
_sym_db.RegisterMessage(CommunitiesAttribute)

OriginatorIdAttribute = _reflection.GeneratedProtocolMessageType('OriginatorIdAttribute', (_message.Message,), {
  'DESCRIPTOR' : _ORIGINATORIDATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.OriginatorIdAttribute)
  })
_sym_db.RegisterMessage(OriginatorIdAttribute)

ClusterListAttribute = _reflection.GeneratedProtocolMessageType('ClusterListAttribute', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERLISTATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ClusterListAttribute)
  })
_sym_db.RegisterMessage(ClusterListAttribute)

IPAddressPrefix = _reflection.GeneratedProtocolMessageType('IPAddressPrefix', (_message.Message,), {
  'DESCRIPTOR' : _IPADDRESSPREFIX,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.IPAddressPrefix)
  })
_sym_db.RegisterMessage(IPAddressPrefix)

LabeledIPAddressPrefix = _reflection.GeneratedProtocolMessageType('LabeledIPAddressPrefix', (_message.Message,), {
  'DESCRIPTOR' : _LABELEDIPADDRESSPREFIX,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LabeledIPAddressPrefix)
  })
_sym_db.RegisterMessage(LabeledIPAddressPrefix)

EncapsulationNLRI = _reflection.GeneratedProtocolMessageType('EncapsulationNLRI', (_message.Message,), {
  'DESCRIPTOR' : _ENCAPSULATIONNLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EncapsulationNLRI)
  })
_sym_db.RegisterMessage(EncapsulationNLRI)

RouteDistinguisherTwoOctetASN = _reflection.GeneratedProtocolMessageType('RouteDistinguisherTwoOctetASN', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEDISTINGUISHERTWOOCTETASN,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteDistinguisherTwoOctetASN)
  })
_sym_db.RegisterMessage(RouteDistinguisherTwoOctetASN)

RouteDistinguisherIPAddress = _reflection.GeneratedProtocolMessageType('RouteDistinguisherIPAddress', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEDISTINGUISHERIPADDRESS,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteDistinguisherIPAddress)
  })
_sym_db.RegisterMessage(RouteDistinguisherIPAddress)

RouteDistinguisherFourOctetASN = _reflection.GeneratedProtocolMessageType('RouteDistinguisherFourOctetASN', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEDISTINGUISHERFOUROCTETASN,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteDistinguisherFourOctetASN)
  })
_sym_db.RegisterMessage(RouteDistinguisherFourOctetASN)

EthernetSegmentIdentifier = _reflection.GeneratedProtocolMessageType('EthernetSegmentIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _ETHERNETSEGMENTIDENTIFIER,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EthernetSegmentIdentifier)
  })
_sym_db.RegisterMessage(EthernetSegmentIdentifier)

VPLSNLRI = _reflection.GeneratedProtocolMessageType('VPLSNLRI', (_message.Message,), {
  'DESCRIPTOR' : _VPLSNLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.VPLSNLRI)
  })
_sym_db.RegisterMessage(VPLSNLRI)

EVPNEthernetAutoDiscoveryRoute = _reflection.GeneratedProtocolMessageType('EVPNEthernetAutoDiscoveryRoute', (_message.Message,), {
  'DESCRIPTOR' : _EVPNETHERNETAUTODISCOVERYROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EVPNEthernetAutoDiscoveryRoute)
  })
_sym_db.RegisterMessage(EVPNEthernetAutoDiscoveryRoute)

EVPNMACIPAdvertisementRoute = _reflection.GeneratedProtocolMessageType('EVPNMACIPAdvertisementRoute', (_message.Message,), {
  'DESCRIPTOR' : _EVPNMACIPADVERTISEMENTROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EVPNMACIPAdvertisementRoute)
  })
_sym_db.RegisterMessage(EVPNMACIPAdvertisementRoute)

EVPNInclusiveMulticastEthernetTagRoute = _reflection.GeneratedProtocolMessageType('EVPNInclusiveMulticastEthernetTagRoute', (_message.Message,), {
  'DESCRIPTOR' : _EVPNINCLUSIVEMULTICASTETHERNETTAGROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EVPNInclusiveMulticastEthernetTagRoute)
  })
_sym_db.RegisterMessage(EVPNInclusiveMulticastEthernetTagRoute)

EVPNEthernetSegmentRoute = _reflection.GeneratedProtocolMessageType('EVPNEthernetSegmentRoute', (_message.Message,), {
  'DESCRIPTOR' : _EVPNETHERNETSEGMENTROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EVPNEthernetSegmentRoute)
  })
_sym_db.RegisterMessage(EVPNEthernetSegmentRoute)

EVPNIPPrefixRoute = _reflection.GeneratedProtocolMessageType('EVPNIPPrefixRoute', (_message.Message,), {
  'DESCRIPTOR' : _EVPNIPPREFIXROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EVPNIPPrefixRoute)
  })
_sym_db.RegisterMessage(EVPNIPPrefixRoute)

EVPNIPMSIRoute = _reflection.GeneratedProtocolMessageType('EVPNIPMSIRoute', (_message.Message,), {
  'DESCRIPTOR' : _EVPNIPMSIROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EVPNIPMSIRoute)
  })
_sym_db.RegisterMessage(EVPNIPMSIRoute)

SRPolicyNLRI = _reflection.GeneratedProtocolMessageType('SRPolicyNLRI', (_message.Message,), {
  'DESCRIPTOR' : _SRPOLICYNLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRPolicyNLRI)
  })
_sym_db.RegisterMessage(SRPolicyNLRI)

LabeledVPNIPAddressPrefix = _reflection.GeneratedProtocolMessageType('LabeledVPNIPAddressPrefix', (_message.Message,), {
  'DESCRIPTOR' : _LABELEDVPNIPADDRESSPREFIX,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LabeledVPNIPAddressPrefix)
  })
_sym_db.RegisterMessage(LabeledVPNIPAddressPrefix)

RouteTargetMembershipNLRI = _reflection.GeneratedProtocolMessageType('RouteTargetMembershipNLRI', (_message.Message,), {
  'DESCRIPTOR' : _ROUTETARGETMEMBERSHIPNLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteTargetMembershipNLRI)
  })
_sym_db.RegisterMessage(RouteTargetMembershipNLRI)

FlowSpecIPPrefix = _reflection.GeneratedProtocolMessageType('FlowSpecIPPrefix', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSPECIPPREFIX,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.FlowSpecIPPrefix)
  })
_sym_db.RegisterMessage(FlowSpecIPPrefix)

FlowSpecMAC = _reflection.GeneratedProtocolMessageType('FlowSpecMAC', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSPECMAC,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.FlowSpecMAC)
  })
_sym_db.RegisterMessage(FlowSpecMAC)

FlowSpecComponentItem = _reflection.GeneratedProtocolMessageType('FlowSpecComponentItem', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSPECCOMPONENTITEM,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.FlowSpecComponentItem)
  })
_sym_db.RegisterMessage(FlowSpecComponentItem)

FlowSpecComponent = _reflection.GeneratedProtocolMessageType('FlowSpecComponent', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSPECCOMPONENT,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.FlowSpecComponent)
  })
_sym_db.RegisterMessage(FlowSpecComponent)

FlowSpecNLRI = _reflection.GeneratedProtocolMessageType('FlowSpecNLRI', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSPECNLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.FlowSpecNLRI)
  })
_sym_db.RegisterMessage(FlowSpecNLRI)

VPNFlowSpecNLRI = _reflection.GeneratedProtocolMessageType('VPNFlowSpecNLRI', (_message.Message,), {
  'DESCRIPTOR' : _VPNFLOWSPECNLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.VPNFlowSpecNLRI)
  })
_sym_db.RegisterMessage(VPNFlowSpecNLRI)

OpaqueNLRI = _reflection.GeneratedProtocolMessageType('OpaqueNLRI', (_message.Message,), {
  'DESCRIPTOR' : _OPAQUENLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.OpaqueNLRI)
  })
_sym_db.RegisterMessage(OpaqueNLRI)

LsNodeDescriptor = _reflection.GeneratedProtocolMessageType('LsNodeDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _LSNODEDESCRIPTOR,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsNodeDescriptor)
  })
_sym_db.RegisterMessage(LsNodeDescriptor)

LsLinkDescriptor = _reflection.GeneratedProtocolMessageType('LsLinkDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _LSLINKDESCRIPTOR,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsLinkDescriptor)
  })
_sym_db.RegisterMessage(LsLinkDescriptor)

LsPrefixDescriptor = _reflection.GeneratedProtocolMessageType('LsPrefixDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _LSPREFIXDESCRIPTOR,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsPrefixDescriptor)
  })
_sym_db.RegisterMessage(LsPrefixDescriptor)

LsNodeNLRI = _reflection.GeneratedProtocolMessageType('LsNodeNLRI', (_message.Message,), {
  'DESCRIPTOR' : _LSNODENLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsNodeNLRI)
  })
_sym_db.RegisterMessage(LsNodeNLRI)

LsLinkNLRI = _reflection.GeneratedProtocolMessageType('LsLinkNLRI', (_message.Message,), {
  'DESCRIPTOR' : _LSLINKNLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsLinkNLRI)
  })
_sym_db.RegisterMessage(LsLinkNLRI)

LsPrefixV4NLRI = _reflection.GeneratedProtocolMessageType('LsPrefixV4NLRI', (_message.Message,), {
  'DESCRIPTOR' : _LSPREFIXV4NLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsPrefixV4NLRI)
  })
_sym_db.RegisterMessage(LsPrefixV4NLRI)

LsPrefixV6NLRI = _reflection.GeneratedProtocolMessageType('LsPrefixV6NLRI', (_message.Message,), {
  'DESCRIPTOR' : _LSPREFIXV6NLRI,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsPrefixV6NLRI)
  })
_sym_db.RegisterMessage(LsPrefixV6NLRI)

LsAddrPrefix = _reflection.GeneratedProtocolMessageType('LsAddrPrefix', (_message.Message,), {
  'DESCRIPTOR' : _LSADDRPREFIX,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsAddrPrefix)
  })
_sym_db.RegisterMessage(LsAddrPrefix)

MUPInterworkSegmentDiscoveryRoute = _reflection.GeneratedProtocolMessageType('MUPInterworkSegmentDiscoveryRoute', (_message.Message,), {
  'DESCRIPTOR' : _MUPINTERWORKSEGMENTDISCOVERYROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MUPInterworkSegmentDiscoveryRoute)
  })
_sym_db.RegisterMessage(MUPInterworkSegmentDiscoveryRoute)

MUPDirectSegmentDiscoveryRoute = _reflection.GeneratedProtocolMessageType('MUPDirectSegmentDiscoveryRoute', (_message.Message,), {
  'DESCRIPTOR' : _MUPDIRECTSEGMENTDISCOVERYROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MUPDirectSegmentDiscoveryRoute)
  })
_sym_db.RegisterMessage(MUPDirectSegmentDiscoveryRoute)

MUPType1SessionTransformedRoute = _reflection.GeneratedProtocolMessageType('MUPType1SessionTransformedRoute', (_message.Message,), {
  'DESCRIPTOR' : _MUPTYPE1SESSIONTRANSFORMEDROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MUPType1SessionTransformedRoute)
  })
_sym_db.RegisterMessage(MUPType1SessionTransformedRoute)

MUPType2SessionTransformedRoute = _reflection.GeneratedProtocolMessageType('MUPType2SessionTransformedRoute', (_message.Message,), {
  'DESCRIPTOR' : _MUPTYPE2SESSIONTRANSFORMEDROUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MUPType2SessionTransformedRoute)
  })
_sym_db.RegisterMessage(MUPType2SessionTransformedRoute)

MpReachNLRIAttribute = _reflection.GeneratedProtocolMessageType('MpReachNLRIAttribute', (_message.Message,), {
  'DESCRIPTOR' : _MPREACHNLRIATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MpReachNLRIAttribute)
  })
_sym_db.RegisterMessage(MpReachNLRIAttribute)

MpUnreachNLRIAttribute = _reflection.GeneratedProtocolMessageType('MpUnreachNLRIAttribute', (_message.Message,), {
  'DESCRIPTOR' : _MPUNREACHNLRIATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MpUnreachNLRIAttribute)
  })
_sym_db.RegisterMessage(MpUnreachNLRIAttribute)

TwoOctetAsSpecificExtended = _reflection.GeneratedProtocolMessageType('TwoOctetAsSpecificExtended', (_message.Message,), {
  'DESCRIPTOR' : _TWOOCTETASSPECIFICEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TwoOctetAsSpecificExtended)
  })
_sym_db.RegisterMessage(TwoOctetAsSpecificExtended)

IPv4AddressSpecificExtended = _reflection.GeneratedProtocolMessageType('IPv4AddressSpecificExtended', (_message.Message,), {
  'DESCRIPTOR' : _IPV4ADDRESSSPECIFICEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.IPv4AddressSpecificExtended)
  })
_sym_db.RegisterMessage(IPv4AddressSpecificExtended)

FourOctetAsSpecificExtended = _reflection.GeneratedProtocolMessageType('FourOctetAsSpecificExtended', (_message.Message,), {
  'DESCRIPTOR' : _FOUROCTETASSPECIFICEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.FourOctetAsSpecificExtended)
  })
_sym_db.RegisterMessage(FourOctetAsSpecificExtended)

LinkBandwidthExtended = _reflection.GeneratedProtocolMessageType('LinkBandwidthExtended', (_message.Message,), {
  'DESCRIPTOR' : _LINKBANDWIDTHEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LinkBandwidthExtended)
  })
_sym_db.RegisterMessage(LinkBandwidthExtended)

ValidationExtended = _reflection.GeneratedProtocolMessageType('ValidationExtended', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATIONEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ValidationExtended)
  })
_sym_db.RegisterMessage(ValidationExtended)

ColorExtended = _reflection.GeneratedProtocolMessageType('ColorExtended', (_message.Message,), {
  'DESCRIPTOR' : _COLOREXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ColorExtended)
  })
_sym_db.RegisterMessage(ColorExtended)

EncapExtended = _reflection.GeneratedProtocolMessageType('EncapExtended', (_message.Message,), {
  'DESCRIPTOR' : _ENCAPEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EncapExtended)
  })
_sym_db.RegisterMessage(EncapExtended)

DefaultGatewayExtended = _reflection.GeneratedProtocolMessageType('DefaultGatewayExtended', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTGATEWAYEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DefaultGatewayExtended)
  })
_sym_db.RegisterMessage(DefaultGatewayExtended)

OpaqueExtended = _reflection.GeneratedProtocolMessageType('OpaqueExtended', (_message.Message,), {
  'DESCRIPTOR' : _OPAQUEEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.OpaqueExtended)
  })
_sym_db.RegisterMessage(OpaqueExtended)

ESILabelExtended = _reflection.GeneratedProtocolMessageType('ESILabelExtended', (_message.Message,), {
  'DESCRIPTOR' : _ESILABELEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ESILabelExtended)
  })
_sym_db.RegisterMessage(ESILabelExtended)

ESImportRouteTarget = _reflection.GeneratedProtocolMessageType('ESImportRouteTarget', (_message.Message,), {
  'DESCRIPTOR' : _ESIMPORTROUTETARGET,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ESImportRouteTarget)
  })
_sym_db.RegisterMessage(ESImportRouteTarget)

MacMobilityExtended = _reflection.GeneratedProtocolMessageType('MacMobilityExtended', (_message.Message,), {
  'DESCRIPTOR' : _MACMOBILITYEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MacMobilityExtended)
  })
_sym_db.RegisterMessage(MacMobilityExtended)

RouterMacExtended = _reflection.GeneratedProtocolMessageType('RouterMacExtended', (_message.Message,), {
  'DESCRIPTOR' : _ROUTERMACEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouterMacExtended)
  })
_sym_db.RegisterMessage(RouterMacExtended)

TrafficRateExtended = _reflection.GeneratedProtocolMessageType('TrafficRateExtended', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICRATEEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TrafficRateExtended)
  })
_sym_db.RegisterMessage(TrafficRateExtended)

TrafficActionExtended = _reflection.GeneratedProtocolMessageType('TrafficActionExtended', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICACTIONEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TrafficActionExtended)
  })
_sym_db.RegisterMessage(TrafficActionExtended)

RedirectTwoOctetAsSpecificExtended = _reflection.GeneratedProtocolMessageType('RedirectTwoOctetAsSpecificExtended', (_message.Message,), {
  'DESCRIPTOR' : _REDIRECTTWOOCTETASSPECIFICEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RedirectTwoOctetAsSpecificExtended)
  })
_sym_db.RegisterMessage(RedirectTwoOctetAsSpecificExtended)

RedirectIPv4AddressSpecificExtended = _reflection.GeneratedProtocolMessageType('RedirectIPv4AddressSpecificExtended', (_message.Message,), {
  'DESCRIPTOR' : _REDIRECTIPV4ADDRESSSPECIFICEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RedirectIPv4AddressSpecificExtended)
  })
_sym_db.RegisterMessage(RedirectIPv4AddressSpecificExtended)

RedirectFourOctetAsSpecificExtended = _reflection.GeneratedProtocolMessageType('RedirectFourOctetAsSpecificExtended', (_message.Message,), {
  'DESCRIPTOR' : _REDIRECTFOUROCTETASSPECIFICEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RedirectFourOctetAsSpecificExtended)
  })
_sym_db.RegisterMessage(RedirectFourOctetAsSpecificExtended)

TrafficRemarkExtended = _reflection.GeneratedProtocolMessageType('TrafficRemarkExtended', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICREMARKEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TrafficRemarkExtended)
  })
_sym_db.RegisterMessage(TrafficRemarkExtended)

MUPExtended = _reflection.GeneratedProtocolMessageType('MUPExtended', (_message.Message,), {
  'DESCRIPTOR' : _MUPEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MUPExtended)
  })
_sym_db.RegisterMessage(MUPExtended)

VPLSExtended = _reflection.GeneratedProtocolMessageType('VPLSExtended', (_message.Message,), {
  'DESCRIPTOR' : _VPLSEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.VPLSExtended)
  })
_sym_db.RegisterMessage(VPLSExtended)

UnknownExtended = _reflection.GeneratedProtocolMessageType('UnknownExtended', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UnknownExtended)
  })
_sym_db.RegisterMessage(UnknownExtended)

ExtendedCommunitiesAttribute = _reflection.GeneratedProtocolMessageType('ExtendedCommunitiesAttribute', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDEDCOMMUNITIESATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ExtendedCommunitiesAttribute)
  })
_sym_db.RegisterMessage(ExtendedCommunitiesAttribute)

As4PathAttribute = _reflection.GeneratedProtocolMessageType('As4PathAttribute', (_message.Message,), {
  'DESCRIPTOR' : _AS4PATHATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.As4PathAttribute)
  })
_sym_db.RegisterMessage(As4PathAttribute)

As4AggregatorAttribute = _reflection.GeneratedProtocolMessageType('As4AggregatorAttribute', (_message.Message,), {
  'DESCRIPTOR' : _AS4AGGREGATORATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.As4AggregatorAttribute)
  })
_sym_db.RegisterMessage(As4AggregatorAttribute)

PmsiTunnelAttribute = _reflection.GeneratedProtocolMessageType('PmsiTunnelAttribute', (_message.Message,), {
  'DESCRIPTOR' : _PMSITUNNELATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PmsiTunnelAttribute)
  })
_sym_db.RegisterMessage(PmsiTunnelAttribute)

TunnelEncapSubTLVEncapsulation = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVEncapsulation', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVENCAPSULATION,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVEncapsulation)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVEncapsulation)

TunnelEncapSubTLVProtocol = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVProtocol', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVPROTOCOL,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVProtocol)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVProtocol)

TunnelEncapSubTLVColor = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVColor', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVCOLOR,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVColor)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVColor)

TunnelEncapSubTLVSRPreference = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVSRPreference', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVSRPREFERENCE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVSRPreference)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVSRPreference)

TunnelEncapSubTLVSRCandidatePathName = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVSRCandidatePathName', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVSRCANDIDATEPATHNAME,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVSRCandidatePathName)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVSRCandidatePathName)

TunnelEncapSubTLVSRPriority = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVSRPriority', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVSRPRIORITY,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVSRPriority)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVSRPriority)

TunnelEncapSubTLVSRBindingSID = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVSRBindingSID', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVSRBINDINGSID,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVSRBindingSID)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVSRBindingSID)

SRBindingSID = _reflection.GeneratedProtocolMessageType('SRBindingSID', (_message.Message,), {
  'DESCRIPTOR' : _SRBINDINGSID,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRBindingSID)
  })
_sym_db.RegisterMessage(SRBindingSID)

SRv6EndPointBehavior = _reflection.GeneratedProtocolMessageType('SRv6EndPointBehavior', (_message.Message,), {
  'DESCRIPTOR' : _SRV6ENDPOINTBEHAVIOR,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRv6EndPointBehavior)
  })
_sym_db.RegisterMessage(SRv6EndPointBehavior)

SRv6BindingSID = _reflection.GeneratedProtocolMessageType('SRv6BindingSID', (_message.Message,), {
  'DESCRIPTOR' : _SRV6BINDINGSID,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRv6BindingSID)
  })
_sym_db.RegisterMessage(SRv6BindingSID)

TunnelEncapSubTLVSRENLP = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVSRENLP', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVSRENLP,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVSRENLP)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVSRENLP)

SRWeight = _reflection.GeneratedProtocolMessageType('SRWeight', (_message.Message,), {
  'DESCRIPTOR' : _SRWEIGHT,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRWeight)
  })
_sym_db.RegisterMessage(SRWeight)

SegmentFlags = _reflection.GeneratedProtocolMessageType('SegmentFlags', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTFLAGS,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SegmentFlags)
  })
_sym_db.RegisterMessage(SegmentFlags)

SegmentTypeA = _reflection.GeneratedProtocolMessageType('SegmentTypeA', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTTYPEA,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SegmentTypeA)
  })
_sym_db.RegisterMessage(SegmentTypeA)

SegmentTypeB = _reflection.GeneratedProtocolMessageType('SegmentTypeB', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTTYPEB,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SegmentTypeB)
  })
_sym_db.RegisterMessage(SegmentTypeB)

TunnelEncapSubTLVSRSegmentList = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVSRSegmentList', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVSRSEGMENTLIST,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVSRSegmentList)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVSRSegmentList)

TunnelEncapSubTLVEgressEndpoint = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVEgressEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVEGRESSENDPOINT,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVEgressEndpoint)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVEgressEndpoint)

TunnelEncapSubTLVUDPDestPort = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVUDPDestPort', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVUDPDESTPORT,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVUDPDestPort)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVUDPDestPort)

TunnelEncapSubTLVUnknown = _reflection.GeneratedProtocolMessageType('TunnelEncapSubTLVUnknown', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPSUBTLVUNKNOWN,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapSubTLVUnknown)
  })
_sym_db.RegisterMessage(TunnelEncapSubTLVUnknown)

TunnelEncapTLV = _reflection.GeneratedProtocolMessageType('TunnelEncapTLV', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPTLV,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapTLV)
  })
_sym_db.RegisterMessage(TunnelEncapTLV)

TunnelEncapAttribute = _reflection.GeneratedProtocolMessageType('TunnelEncapAttribute', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELENCAPATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TunnelEncapAttribute)
  })
_sym_db.RegisterMessage(TunnelEncapAttribute)

IPv6AddressSpecificExtended = _reflection.GeneratedProtocolMessageType('IPv6AddressSpecificExtended', (_message.Message,), {
  'DESCRIPTOR' : _IPV6ADDRESSSPECIFICEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.IPv6AddressSpecificExtended)
  })
_sym_db.RegisterMessage(IPv6AddressSpecificExtended)

RedirectIPv6AddressSpecificExtended = _reflection.GeneratedProtocolMessageType('RedirectIPv6AddressSpecificExtended', (_message.Message,), {
  'DESCRIPTOR' : _REDIRECTIPV6ADDRESSSPECIFICEXTENDED,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RedirectIPv6AddressSpecificExtended)
  })
_sym_db.RegisterMessage(RedirectIPv6AddressSpecificExtended)

IP6ExtendedCommunitiesAttribute = _reflection.GeneratedProtocolMessageType('IP6ExtendedCommunitiesAttribute', (_message.Message,), {
  'DESCRIPTOR' : _IP6EXTENDEDCOMMUNITIESATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.IP6ExtendedCommunitiesAttribute)
  })
_sym_db.RegisterMessage(IP6ExtendedCommunitiesAttribute)

AigpTLVIGPMetric = _reflection.GeneratedProtocolMessageType('AigpTLVIGPMetric', (_message.Message,), {
  'DESCRIPTOR' : _AIGPTLVIGPMETRIC,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AigpTLVIGPMetric)
  })
_sym_db.RegisterMessage(AigpTLVIGPMetric)

AigpTLVUnknown = _reflection.GeneratedProtocolMessageType('AigpTLVUnknown', (_message.Message,), {
  'DESCRIPTOR' : _AIGPTLVUNKNOWN,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AigpTLVUnknown)
  })
_sym_db.RegisterMessage(AigpTLVUnknown)

AigpAttribute = _reflection.GeneratedProtocolMessageType('AigpAttribute', (_message.Message,), {
  'DESCRIPTOR' : _AIGPATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AigpAttribute)
  })
_sym_db.RegisterMessage(AigpAttribute)

LargeCommunity = _reflection.GeneratedProtocolMessageType('LargeCommunity', (_message.Message,), {
  'DESCRIPTOR' : _LARGECOMMUNITY,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LargeCommunity)
  })
_sym_db.RegisterMessage(LargeCommunity)

LargeCommunitiesAttribute = _reflection.GeneratedProtocolMessageType('LargeCommunitiesAttribute', (_message.Message,), {
  'DESCRIPTOR' : _LARGECOMMUNITIESATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LargeCommunitiesAttribute)
  })
_sym_db.RegisterMessage(LargeCommunitiesAttribute)

LsNodeFlags = _reflection.GeneratedProtocolMessageType('LsNodeFlags', (_message.Message,), {
  'DESCRIPTOR' : _LSNODEFLAGS,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsNodeFlags)
  })
_sym_db.RegisterMessage(LsNodeFlags)

LsIGPFlags = _reflection.GeneratedProtocolMessageType('LsIGPFlags', (_message.Message,), {
  'DESCRIPTOR' : _LSIGPFLAGS,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsIGPFlags)
  })
_sym_db.RegisterMessage(LsIGPFlags)

LsSrRange = _reflection.GeneratedProtocolMessageType('LsSrRange', (_message.Message,), {
  'DESCRIPTOR' : _LSSRRANGE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsSrRange)
  })
_sym_db.RegisterMessage(LsSrRange)

LsSrCapabilities = _reflection.GeneratedProtocolMessageType('LsSrCapabilities', (_message.Message,), {
  'DESCRIPTOR' : _LSSRCAPABILITIES,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsSrCapabilities)
  })
_sym_db.RegisterMessage(LsSrCapabilities)

LsSrLocalBlock = _reflection.GeneratedProtocolMessageType('LsSrLocalBlock', (_message.Message,), {
  'DESCRIPTOR' : _LSSRLOCALBLOCK,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsSrLocalBlock)
  })
_sym_db.RegisterMessage(LsSrLocalBlock)

LsAttributeNode = _reflection.GeneratedProtocolMessageType('LsAttributeNode', (_message.Message,), {
  'DESCRIPTOR' : _LSATTRIBUTENODE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsAttributeNode)
  })
_sym_db.RegisterMessage(LsAttributeNode)

LsAttributeLink = _reflection.GeneratedProtocolMessageType('LsAttributeLink', (_message.Message,), {
  'DESCRIPTOR' : _LSATTRIBUTELINK,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsAttributeLink)
  })
_sym_db.RegisterMessage(LsAttributeLink)

LsAttributePrefix = _reflection.GeneratedProtocolMessageType('LsAttributePrefix', (_message.Message,), {
  'DESCRIPTOR' : _LSATTRIBUTEPREFIX,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsAttributePrefix)
  })
_sym_db.RegisterMessage(LsAttributePrefix)

LsBgpPeerSegmentSIDFlags = _reflection.GeneratedProtocolMessageType('LsBgpPeerSegmentSIDFlags', (_message.Message,), {
  'DESCRIPTOR' : _LSBGPPEERSEGMENTSIDFLAGS,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsBgpPeerSegmentSIDFlags)
  })
_sym_db.RegisterMessage(LsBgpPeerSegmentSIDFlags)

LsBgpPeerSegmentSID = _reflection.GeneratedProtocolMessageType('LsBgpPeerSegmentSID', (_message.Message,), {
  'DESCRIPTOR' : _LSBGPPEERSEGMENTSID,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsBgpPeerSegmentSID)
  })
_sym_db.RegisterMessage(LsBgpPeerSegmentSID)

LsAttributeBgpPeerSegment = _reflection.GeneratedProtocolMessageType('LsAttributeBgpPeerSegment', (_message.Message,), {
  'DESCRIPTOR' : _LSATTRIBUTEBGPPEERSEGMENT,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsAttributeBgpPeerSegment)
  })
_sym_db.RegisterMessage(LsAttributeBgpPeerSegment)

LsAttribute = _reflection.GeneratedProtocolMessageType('LsAttribute', (_message.Message,), {
  'DESCRIPTOR' : _LSATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LsAttribute)
  })
_sym_db.RegisterMessage(LsAttribute)

UnknownAttribute = _reflection.GeneratedProtocolMessageType('UnknownAttribute', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNATTRIBUTE,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UnknownAttribute)
  })
_sym_db.RegisterMessage(UnknownAttribute)

SRv6StructureSubSubTLV = _reflection.GeneratedProtocolMessageType('SRv6StructureSubSubTLV', (_message.Message,), {
  'DESCRIPTOR' : _SRV6STRUCTURESUBSUBTLV,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRv6StructureSubSubTLV)
  })
_sym_db.RegisterMessage(SRv6StructureSubSubTLV)

SRv6SIDFlags = _reflection.GeneratedProtocolMessageType('SRv6SIDFlags', (_message.Message,), {
  'DESCRIPTOR' : _SRV6SIDFLAGS,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRv6SIDFlags)
  })
_sym_db.RegisterMessage(SRv6SIDFlags)

SRv6TLV = _reflection.GeneratedProtocolMessageType('SRv6TLV', (_message.Message,), {
  'DESCRIPTOR' : _SRV6TLV,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRv6TLV)
  })
_sym_db.RegisterMessage(SRv6TLV)

SRv6InformationSubTLV = _reflection.GeneratedProtocolMessageType('SRv6InformationSubTLV', (_message.Message,), {

  'SubSubTlvsEntry' : _reflection.GeneratedProtocolMessageType('SubSubTlvsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SRV6INFORMATIONSUBTLV_SUBSUBTLVSENTRY,
    '__module__' : 'attribute_pb2'
    # @@protoc_insertion_point(class_scope:apipb.SRv6InformationSubTLV.SubSubTlvsEntry)
    })
  ,
  'DESCRIPTOR' : _SRV6INFORMATIONSUBTLV,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRv6InformationSubTLV)
  })
_sym_db.RegisterMessage(SRv6InformationSubTLV)
_sym_db.RegisterMessage(SRv6InformationSubTLV.SubSubTlvsEntry)

SRv6L3ServiceTLV = _reflection.GeneratedProtocolMessageType('SRv6L3ServiceTLV', (_message.Message,), {

  'SubTlvsEntry' : _reflection.GeneratedProtocolMessageType('SubTlvsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SRV6L3SERVICETLV_SUBTLVSENTRY,
    '__module__' : 'attribute_pb2'
    # @@protoc_insertion_point(class_scope:apipb.SRv6L3ServiceTLV.SubTlvsEntry)
    })
  ,
  'DESCRIPTOR' : _SRV6L3SERVICETLV,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRv6L3ServiceTLV)
  })
_sym_db.RegisterMessage(SRv6L3ServiceTLV)
_sym_db.RegisterMessage(SRv6L3ServiceTLV.SubTlvsEntry)

SRv6L2ServiceTLV = _reflection.GeneratedProtocolMessageType('SRv6L2ServiceTLV', (_message.Message,), {

  'SubTlvsEntry' : _reflection.GeneratedProtocolMessageType('SubTlvsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SRV6L2SERVICETLV_SUBTLVSENTRY,
    '__module__' : 'attribute_pb2'
    # @@protoc_insertion_point(class_scope:apipb.SRv6L2ServiceTLV.SubTlvsEntry)
    })
  ,
  'DESCRIPTOR' : _SRV6L2SERVICETLV,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SRv6L2ServiceTLV)
  })
_sym_db.RegisterMessage(SRv6L2ServiceTLV)
_sym_db.RegisterMessage(SRv6L2ServiceTLV.SubTlvsEntry)

PrefixSID = _reflection.GeneratedProtocolMessageType('PrefixSID', (_message.Message,), {
  'DESCRIPTOR' : _PREFIXSID,
  '__module__' : 'attribute_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PrefixSID)
  })
_sym_db.RegisterMessage(PrefixSID)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/osrg/gobgp/v3/api;apipb'
  _MUPTYPE1SESSIONTRANSFORMEDROUTE.fields_by_name['prefix_length']._options = None
  _MUPTYPE1SESSIONTRANSFORMEDROUTE.fields_by_name['prefix_length']._serialized_options = b'\030\001'
  _SRV6INFORMATIONSUBTLV_SUBSUBTLVSENTRY._options = None
  _SRV6INFORMATIONSUBTLV_SUBSUBTLVSENTRY._serialized_options = b'8\001'
  _SRV6L3SERVICETLV_SUBTLVSENTRY._options = None
  _SRV6L3SERVICETLV_SUBTLVSENTRY._serialized_options = b'8\001'
  _SRV6L2SERVICETLV_SUBTLVSENTRY._options = None
  _SRV6L2SERVICETLV_SUBTLVSENTRY._serialized_options = b'8\001'
  _LSOSPFROUTETYPE._serialized_start=10898
  _LSOSPFROUTETYPE._serialized_end=11145
  _LSNLRITYPE._serialized_start=11147
  _LSNLRITYPE._serialized_end=11262
  _LSPROTOCOLID._serialized_start=11265
  _LSPROTOCOLID._serialized_end=11452
  _SRV6BEHAVIOR._serialized_start=11455
  _SRV6BEHAVIOR._serialized_end=12204
  _ENLPTYPE._serialized_start=12206
  _ENLPTYPE._serialized_end=12274
  _ORIGINATTRIBUTE._serialized_start=66
  _ORIGINATTRIBUTE._serialized_end=99
  _ASSEGMENT._serialized_start=102
  _ASSEGMENT._serialized_end=260
  _ASSEGMENT_TYPE._serialized_start=169
  _ASSEGMENT_TYPE._serialized_end=260
  _ASPATHATTRIBUTE._serialized_start=262
  _ASPATHATTRIBUTE._serialized_end=315
  _NEXTHOPATTRIBUTE._serialized_start=317
  _NEXTHOPATTRIBUTE._serialized_end=353
  _MULTIEXITDISCATTRIBUTE._serialized_start=355
  _MULTIEXITDISCATTRIBUTE._serialized_end=392
  _LOCALPREFATTRIBUTE._serialized_start=394
  _LOCALPREFATTRIBUTE._serialized_end=434
  _ATOMICAGGREGATEATTRIBUTE._serialized_start=436
  _ATOMICAGGREGATEATTRIBUTE._serialized_end=462
  _AGGREGATORATTRIBUTE._serialized_start=464
  _AGGREGATORATTRIBUTE._serialized_end=515
  _COMMUNITIESATTRIBUTE._serialized_start=517
  _COMMUNITIESATTRIBUTE._serialized_end=560
  _ORIGINATORIDATTRIBUTE._serialized_start=562
  _ORIGINATORIDATTRIBUTE._serialized_end=597
  _CLUSTERLISTATTRIBUTE._serialized_start=599
  _CLUSTERLISTATTRIBUTE._serialized_end=634
  _IPADDRESSPREFIX._serialized_start=636
  _IPADDRESSPREFIX._serialized_end=689
  _LABELEDIPADDRESSPREFIX._serialized_start=691
  _LABELEDIPADDRESSPREFIX._serialized_end=767
  _ENCAPSULATIONNLRI._serialized_start=769
  _ENCAPSULATIONNLRI._serialized_end=805
  _ROUTEDISTINGUISHERTWOOCTETASN._serialized_start=807
  _ROUTEDISTINGUISHERTWOOCTETASN._serialized_end=871
  _ROUTEDISTINGUISHERIPADDRESS._serialized_start=873
  _ROUTEDISTINGUISHERIPADDRESS._serialized_end=935
  _ROUTEDISTINGUISHERFOUROCTETASN._serialized_start=937
  _ROUTEDISTINGUISHERFOUROCTETASN._serialized_end=1002
  _ETHERNETSEGMENTIDENTIFIER._serialized_start=1004
  _ETHERNETSEGMENTIDENTIFIER._serialized_end=1060
  _VPLSNLRI._serialized_start=1063
  _VPLSNLRI._serialized_end=1196
  _EVPNETHERNETAUTODISCOVERYROUTE._serialized_start=1199
  _EVPNETHERNETAUTODISCOVERYROUTE._serialized_end=1349
  _EVPNMACIPADVERTISEMENTROUTE._serialized_start=1352
  _EVPNMACIPADVERTISEMENTROUTE._serialized_end=1541
  _EVPNINCLUSIVEMULTICASTETHERNETTAGROUTE._serialized_start=1543
  _EVPNINCLUSIVEMULTICASTETHERNETTAGROUTE._serialized_end=1659
  _EVPNETHERNETSEGMENTROUTE._serialized_start=1661
  _EVPNETHERNETSEGMENTROUTE._serialized_end=1788
  _EVPNIPPREFIXROUTE._serialized_start=1791
  _EVPNIPPREFIXROUTE._serialized_end=1990
  _EVPNIPMSIROUTE._serialized_start=1992
  _EVPNIPMSIROUTE._serialized_end=2098
  _SRPOLICYNLRI._serialized_start=2100
  _SRPOLICYNLRI._serialized_end=2186
  _LABELEDVPNIPADDRESSPREFIX._serialized_start=2188
  _LABELEDVPNIPADDRESSPREFIX._serialized_end=2301
  _ROUTETARGETMEMBERSHIPNLRI._serialized_start=2303
  _ROUTETARGETMEMBERSHIPNLRI._serialized_end=2377
  _FLOWSPECIPPREFIX._serialized_start=2379
  _FLOWSPECIPPREFIX._serialized_end=2463
  _FLOWSPECMAC._serialized_start=2465
  _FLOWSPECMAC._serialized_end=2509
  _FLOWSPECCOMPONENTITEM._serialized_start=2511
  _FLOWSPECCOMPONENTITEM._serialized_end=2561
  _FLOWSPECCOMPONENT._serialized_start=2563
  _FLOWSPECCOMPONENT._serialized_end=2641
  _FLOWSPECNLRI._serialized_start=2643
  _FLOWSPECNLRI._serialized_end=2694
  _VPNFLOWSPECNLRI._serialized_start=2696
  _VPNFLOWSPECNLRI._serialized_end=2784
  _OPAQUENLRI._serialized_start=2786
  _OPAQUENLRI._serialized_end=2826
  _LSNODEDESCRIPTOR._serialized_start=2829
  _LSNODEDESCRIPTOR._serialized_end=3001
  _LSLINKDESCRIPTOR._serialized_start=3004
  _LSLINKDESCRIPTOR._serialized_end=3183
  _LSPREFIXDESCRIPTOR._serialized_start=3185
  _LSPREFIXDESCRIPTOR._serialized_end=3279
  _LSNODENLRI._serialized_start=3281
  _LSNODENLRI._serialized_end=3338
  _LSLINKNLRI._serialized_start=3341
  _LSLINKNLRI._serialized_end=3494
  _LSPREFIXV4NLRI._serialized_start=3496
  _LSPREFIXV4NLRI._serialized_end=3611
  _LSPREFIXV6NLRI._serialized_start=3613
  _LSPREFIXV6NLRI._serialized_end=3728
  _LSADDRPREFIX._serialized_start=3731
  _LSADDRPREFIX._serialized_end=3892
  _MUPINTERWORKSEGMENTDISCOVERYROUTE._serialized_start=3894
  _MUPINTERWORKSEGMENTDISCOVERYROUTE._serialized_end=3979
  _MUPDIRECTSEGMENTDISCOVERYROUTE._serialized_start=3981
  _MUPDIRECTSEGMENTDISCOVERYROUTE._serialized_end=4064
  _MUPTYPE1SESSIONTRANSFORMEDROUTE._serialized_start=4067
  _MUPTYPE1SESSIONTRANSFORMEDROUTE._serialized_end=4263
  _MUPTYPE2SESSIONTRANSFORMEDROUTE._serialized_start=4266
  _MUPTYPE2SESSIONTRANSFORMEDROUTE._serialized_end=4406
  _MPREACHNLRIATTRIBUTE._serialized_start=4408
  _MPREACHNLRIATTRIBUTE._serialized_end=4517
  _MPUNREACHNLRIATTRIBUTE._serialized_start=4519
  _MPUNREACHNLRIATTRIBUTE._serialized_end=4611
  _TWOOCTETASSPECIFICEXTENDED._serialized_start=4613
  _TWOOCTETASSPECIFICEXTENDED._serialized_end=4716
  _IPV4ADDRESSSPECIFICEXTENDED._serialized_start=4718
  _IPV4ADDRESSSPECIFICEXTENDED._serialized_end=4826
  _FOUROCTETASSPECIFICEXTENDED._serialized_start=4828
  _FOUROCTETASSPECIFICEXTENDED._serialized_end=4932
  _LINKBANDWIDTHEXTENDED._serialized_start=4934
  _LINKBANDWIDTHEXTENDED._serialized_end=4989
  _VALIDATIONEXTENDED._serialized_start=4991
  _VALIDATIONEXTENDED._serialized_end=5026
  _COLOREXTENDED._serialized_start=5028
  _COLOREXTENDED._serialized_end=5058
  _ENCAPEXTENDED._serialized_start=5060
  _ENCAPEXTENDED._serialized_end=5096
  _DEFAULTGATEWAYEXTENDED._serialized_start=5098
  _DEFAULTGATEWAYEXTENDED._serialized_end=5122
  _OPAQUEEXTENDED._serialized_start=5124
  _OPAQUEEXTENDED._serialized_end=5178
  _ESILABELEXTENDED._serialized_start=5180
  _ESILABELEXTENDED._serialized_end=5239
  _ESIMPORTROUTETARGET._serialized_start=5241
  _ESIMPORTROUTETARGET._serialized_end=5281
  _MACMOBILITYEXTENDED._serialized_start=5283
  _MACMOBILITYEXTENDED._serialized_end=5345
  _ROUTERMACEXTENDED._serialized_start=5347
  _ROUTERMACEXTENDED._serialized_end=5379
  _TRAFFICRATEEXTENDED._serialized_start=5381
  _TRAFFICRATEEXTENDED._serialized_end=5429
  _TRAFFICACTIONEXTENDED._serialized_start=5431
  _TRAFFICACTIONEXTENDED._serialized_end=5488
  _REDIRECTTWOOCTETASSPECIFICEXTENDED._serialized_start=5490
  _REDIRECTTWOOCTETASSPECIFICEXTENDED._serialized_end=5560
  _REDIRECTIPV4ADDRESSSPECIFICEXTENDED._serialized_start=5562
  _REDIRECTIPV4ADDRESSSPECIFICEXTENDED._serialized_end=5637
  _REDIRECTFOUROCTETASSPECIFICEXTENDED._serialized_start=5639
  _REDIRECTFOUROCTETASSPECIFICEXTENDED._serialized_end=5710
  _TRAFFICREMARKEXTENDED._serialized_start=5712
  _TRAFFICREMARKEXTENDED._serialized_end=5749
  _MUPEXTENDED._serialized_start=5751
  _MUPEXTENDED._serialized_end=5824
  _VPLSEXTENDED._serialized_start=5826
  _VPLSEXTENDED._serialized_end=5876
  _UNKNOWNEXTENDED._serialized_start=5878
  _UNKNOWNEXTENDED._serialized_end=5924
  _EXTENDEDCOMMUNITIESATTRIBUTE._serialized_start=5926
  _EXTENDEDCOMMUNITIESATTRIBUTE._serialized_end=5999
  _AS4PATHATTRIBUTE._serialized_start=6001
  _AS4PATHATTRIBUTE._serialized_end=6055
  _AS4AGGREGATORATTRIBUTE._serialized_start=6057
  _AS4AGGREGATORATTRIBUTE._serialized_end=6111
  _PMSITUNNELATTRIBUTE._serialized_start=6113
  _PMSITUNNELATTRIBUTE._serialized_end=6190
  _TUNNELENCAPSUBTLVENCAPSULATION._serialized_start=6192
  _TUNNELENCAPSUBTLVENCAPSULATION._serialized_end=6253
  _TUNNELENCAPSUBTLVPROTOCOL._serialized_start=6255
  _TUNNELENCAPSUBTLVPROTOCOL._serialized_end=6300
  _TUNNELENCAPSUBTLVCOLOR._serialized_start=6302
  _TUNNELENCAPSUBTLVCOLOR._serialized_end=6341
  _TUNNELENCAPSUBTLVSRPREFERENCE._serialized_start=6343
  _TUNNELENCAPSUBTLVSRPREFERENCE._serialized_end=6409
  _TUNNELENCAPSUBTLVSRCANDIDATEPATHNAME._serialized_start=6411
  _TUNNELENCAPSUBTLVSRCANDIDATEPATHNAME._serialized_end=6478
  _TUNNELENCAPSUBTLVSRPRIORITY._serialized_start=6480
  _TUNNELENCAPSUBTLVSRPRIORITY._serialized_end=6527
  _TUNNELENCAPSUBTLVSRBINDINGSID._serialized_start=6529
  _TUNNELENCAPSUBTLVSRBINDINGSID._serialized_end=6596
  _SRBINDINGSID._serialized_start=6598
  _SRBINDINGSID._serialized_end=6657
  _SRV6ENDPOINTBEHAVIOR._serialized_start=6660
  _SRV6ENDPOINTBEHAVIOR._serialized_end=6793
  _SRV6BINDINGSID._serialized_start=6796
  _SRV6BINDINGSID._serialized_end=6939
  _TUNNELENCAPSUBTLVSRENLP._serialized_start=6941
  _TUNNELENCAPSUBTLVSRENLP._serialized_end=7012
  _SRWEIGHT._serialized_start=7014
  _SRWEIGHT._serialized_end=7055
  _SEGMENTFLAGS._serialized_start=7057
  _SEGMENTFLAGS._serialized_end=7135
  _SEGMENTTYPEA._serialized_start=7137
  _SEGMENTTYPEA._serialized_end=7202
  _SEGMENTTYPEB._serialized_start=7205
  _SEGMENTTYPEB._serialized_end=7334
  _TUNNELENCAPSUBTLVSRSEGMENTLIST._serialized_start=7336
  _TUNNELENCAPSUBTLVSRSEGMENTLIST._serialized_end=7441
  _TUNNELENCAPSUBTLVEGRESSENDPOINT._serialized_start=7443
  _TUNNELENCAPSUBTLVEGRESSENDPOINT._serialized_end=7493
  _TUNNELENCAPSUBTLVUDPDESTPORT._serialized_start=7495
  _TUNNELENCAPSUBTLVUDPDESTPORT._serialized_end=7539
  _TUNNELENCAPSUBTLVUNKNOWN._serialized_start=7541
  _TUNNELENCAPSUBTLVUNKNOWN._serialized_end=7596
  _TUNNELENCAPTLV._serialized_start=7598
  _TUNNELENCAPTLV._serialized_end=7664
  _TUNNELENCAPATTRIBUTE._serialized_start=7666
  _TUNNELENCAPATTRIBUTE._serialized_end=7725
  _IPV6ADDRESSSPECIFICEXTENDED._serialized_start=7727
  _IPV6ADDRESSSPECIFICEXTENDED._serialized_end=7835
  _REDIRECTIPV6ADDRESSSPECIFICEXTENDED._serialized_start=7837
  _REDIRECTIPV6ADDRESSSPECIFICEXTENDED._serialized_end=7912
  _IP6EXTENDEDCOMMUNITIESATTRIBUTE._serialized_start=7914
  _IP6EXTENDEDCOMMUNITIESATTRIBUTE._serialized_end=7990
  _AIGPTLVIGPMETRIC._serialized_start=7992
  _AIGPTLVIGPMETRIC._serialized_end=8026
  _AIGPTLVUNKNOWN._serialized_start=8028
  _AIGPTLVUNKNOWN._serialized_end=8073
  _AIGPATTRIBUTE._serialized_start=8075
  _AIGPATTRIBUTE._serialized_end=8126
  _LARGECOMMUNITY._serialized_start=8128
  _LARGECOMMUNITY._serialized_end=8208
  _LARGECOMMUNITIESATTRIBUTE._serialized_start=8210
  _LARGECOMMUNITIESATTRIBUTE._serialized_end=8281
  _LSNODEFLAGS._serialized_start=8283
  _LSNODEFLAGS._serialized_end=8391
  _LSIGPFLAGS._serialized_start=8393
  _LSIGPFLAGS._serialized_end=8486
  _LSSRRANGE._serialized_start=8488
  _LSSRRANGE._serialized_end=8527
  _LSSRCAPABILITIES._serialized_start=8529
  _LSSRCAPABILITIES._serialized_end=8629
  _LSSRLOCALBLOCK._serialized_start=8631
  _LSSRLOCALBLOCK._serialized_end=8681
  _LSATTRIBUTENODE._serialized_start=8684
  _LSATTRIBUTENODE._serialized_end=8958
  _LSATTRIBUTELINK._serialized_start=8961
  _LSATTRIBUTELINK._serialized_end=9304
  _LSATTRIBUTEPREFIX._serialized_start=9306
  _LSATTRIBUTEPREFIX._serialized_end=9402
  _LSBGPPEERSEGMENTSIDFLAGS._serialized_start=9404
  _LSBGPPEERSEGMENTSIDFLAGS._serialized_end=9496
  _LSBGPPEERSEGMENTSID._serialized_start=9498
  _LSBGPPEERSEGMENTSID._serialized_end=9596
  _LSATTRIBUTEBGPPEERSEGMENT._serialized_start=9599
  _LSATTRIBUTEBGPPEERSEGMENT._serialized_end=9795
  _LSATTRIBUTE._serialized_start=9798
  _LSATTRIBUTE._serialized_end=9989
  _UNKNOWNATTRIBUTE._serialized_start=9991
  _UNKNOWNATTRIBUTE._serialized_end=10053
  _SRV6STRUCTURESUBSUBTLV._serialized_start=10056
  _SRV6STRUCTURESUBSUBTLV._serialized_end=10249
  _SRV6SIDFLAGS._serialized_start=10251
  _SRV6SIDFLAGS._serialized_end=10281
  _SRV6TLV._serialized_start=10283
  _SRV6TLV._serialized_end=10327
  _SRV6INFORMATIONSUBTLV._serialized_start=10330
  _SRV6INFORMATIONSUBTLV._serialized_end=10564
  _SRV6INFORMATIONSUBTLV_SUBSUBTLVSENTRY._serialized_start=10499
  _SRV6INFORMATIONSUBTLV_SUBSUBTLVSENTRY._serialized_end=10564
  _SRV6L3SERVICETLV._serialized_start=10567
  _SRV6L3SERVICETLV._serialized_end=10705
  _SRV6L3SERVICETLV_SUBTLVSENTRY._serialized_start=10643
  _SRV6L3SERVICETLV_SUBTLVSENTRY._serialized_end=10705
  _SRV6L2SERVICETLV._serialized_start=10708
  _SRV6L2SERVICETLV._serialized_end=10846
  _SRV6L2SERVICETLV_SUBTLVSENTRY._serialized_start=10643
  _SRV6L2SERVICETLV_SUBTLVSENTRY._serialized_end=10705
  _PREFIXSID._serialized_start=10848
  _PREFIXSID._serialized_end=10895
# @@protoc_insertion_point(module_scope)



# vim: tabstop=4 shiftwidth=4 softtabstop=4
#
#    Copyright 2022 VK Cloud.
#
#    All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
import sys

from oslo_config import cfg

from evpn_connector.bgp import client as bgp_client
from evpn_connector.common import conf_opts
from evpn_connector.common import config
from evpn_connector.common import constants
from evpn_connector.common import log as evpn_log
from evpn_connector.common import metrics
from evpn_connector.common import sentry
from evpn_connector.ovs import client as ovs_client
from evpn_connector.service import evpn


OBSENDER_APP_NAME = constants.GLOBAL_SERVICE_NAME
EVENT_TYPE = "%s.service.soft_irq.iteration_step" % OBSENDER_APP_NAME
ERROR_EVENT_TYPE = "%s.error" % EVENT_TYPE
SENTRY_SERVICE_NAME = "%s_%s" % (constants.GLOBAL_SERVICE_NAME, "connector")

CONF = cfg.CONF

conf_opts.register_victoria_metrics_opts()
conf_opts.register_sentry_opts()
conf_opts.register_logging_opts()
conf_opts.register_daemon_opts()
conf_opts.register_gobgp_opts()
conf_opts.register_ovs_opts()
conf_opts.register_anycast_opts()


def main():
    # Parse config
    config.parse(sys.argv[1:])

    sentry.setup_sentry(service=SENTRY_SERVICE_NAME)

    # Configure logging
    evpn_log.configure(
        service_name=constants.GLOBAL_SERVICE_NAME,
        config_file_path=CONF.find_file(CONF.logging.config),
    )

    log = logging.getLogger(__name__)
    sender = metrics.get_sender(OBSENDER_APP_NAME, log)

    # Init gobgp client
    gobgp_client = bgp_client.BGPClient(
        gobgp_channel=CONF.gobgp.gobgp_channel,
        grpc_timeout_sec=CONF.gobgp.grpc_timeout_sec,
        router_mac_type5=CONF.gobgp.router_mac_type5,
    )

    # Init ovs client
    shell_ovs_client = ovs_client.OvSClient(
        sw_name=CONF.ovs.switch_name,
        tmp_flow_file_path=CONF.ovs.tmp_flow_file_path,
        enable_sudo=CONF.ovs.enable_sudo,
        ovsvsctl_bin=CONF.ovs.ovs_vsctl_bin_path,
        ovsofctl_bin=CONF.ovs.ovs_ofctl_bin_path,
    )

    # Start service
    service = evpn.EvpnConnectorService(
        gobgp_client=gobgp_client,
        ovs_client=shell_ovs_client,
        source_ip=CONF.gobgp.source_ip,
        vxlan_udp_port=CONF.ovs.vxlan_udp_port,
        as_number=CONF.gobgp.as_number,
        policy_enabled=CONF.gobgp.policy_enabled,
        configs_dir=CONF.daemon.configs_dir,
        router_mac_type5=CONF.gobgp.router_mac_type5,
        anycast_status_file=CONF.anycast.anycast_status_file,
        anycast_check_ofport=CONF.anycast.anycast_check_ofport,
        anycast_check_mac=CONF.anycast.anycast_check_mac,
        sender=sender,
        step_period=CONF.daemon.sync_period,
        event_type=EVENT_TYPE,
        error_event_type=ERROR_EVENT_TYPE,
    )
    log.info("Start %s service as daemon", constants.GLOBAL_SERVICE_NAME)
    service.serve()
    log.info("Stop %s service.", constants.GLOBAL_SERVICE_NAME)


if __name__ == "__main__":
    main()
